@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2024 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -28,6 +28,7 @@
 #ifdef HAVE_XINPUT_H
 #if defined(__XBOXONE__) || defined(__XBOXSERIES__)
 /* Xbox supports an XInput wrapper which is a C++-only header... */
+#include <math.h> /* Required to compile with recent MSVC... */
 #include <XInputOnGameInput.h>
 using namespace XInputOnGameInput;
 #else
@@ -39,11 +40,14 @@ using namespace XInputOnGameInput;
 #define XUSER_MAX_COUNT 4
 #endif
 #ifndef XUSER_INDEX_ANY
-#define XUSER_INDEX_ANY     0x000000FF
+#define XUSER_INDEX_ANY 0x000000FF
 #endif
 #ifndef XINPUT_CAPS_FFB_SUPPORTED
 #define XINPUT_CAPS_FFB_SUPPORTED 0x0001
 #endif
+#ifndef XINPUT_CAPS_WIRELESS
+#define XINPUT_CAPS_WIRELESS 0x0002
+#endif
 
 #ifndef XINPUT_DEVSUBTYPE_UNKNOWN
 #define XINPUT_DEVSUBTYPE_UNKNOWN 0x00
@@ -131,29 +135,29 @@ using namespace XInputOnGameInput;
 #endif
 
 #ifndef BATTERY_DEVTYPE_GAMEPAD
-#define BATTERY_DEVTYPE_GAMEPAD         0x00
+#define BATTERY_DEVTYPE_GAMEPAD 0x00
 #endif
 
 #ifndef BATTERY_TYPE_DISCONNECTED
-#define BATTERY_TYPE_DISCONNECTED       0x00
+#define BATTERY_TYPE_DISCONNECTED 0x00
 #endif
 #ifndef BATTERY_TYPE_WIRED
-#define BATTERY_TYPE_WIRED              0x01
+#define BATTERY_TYPE_WIRED 0x01
 #endif
 #ifndef BATTERY_TYPE_UNKNOWN
-#define BATTERY_TYPE_UNKNOWN            0xFF
+#define BATTERY_TYPE_UNKNOWN 0xFF
 #endif
 #ifndef BATTERY_LEVEL_EMPTY
-#define BATTERY_LEVEL_EMPTY             0x00
+#define BATTERY_LEVEL_EMPTY 0x00
 #endif
 #ifndef BATTERY_LEVEL_LOW
-#define BATTERY_LEVEL_LOW               0x01
+#define BATTERY_LEVEL_LOW 0x01
 #endif
 #ifndef BATTERY_LEVEL_MEDIUM
-#define BATTERY_LEVEL_MEDIUM            0x02
+#define BATTERY_LEVEL_MEDIUM 0x02
 #endif
 #ifndef BATTERY_LEVEL_FULL
-#define BATTERY_LEVEL_FULL              0x03
+#define BATTERY_LEVEL_FULL 0x03
 #endif
 
 /* Set up for C function definitions, even when using C++ */
@@ -163,28 +167,8 @@ extern "C" {
 
 /* typedef's for XInput structs we use */
 
-#ifndef HAVE_XINPUT_GAMEPAD_EX
-typedef struct
-{
-    WORD wButtons;
-    BYTE bLeftTrigger;
-    BYTE bRightTrigger;
-    SHORT sThumbLX;
-    SHORT sThumbLY;
-    SHORT sThumbRX;
-    SHORT sThumbRY;
-    DWORD dwPaddingReserved;
-} XINPUT_GAMEPAD_EX;
-#endif
-
-#ifndef HAVE_XINPUT_STATE_EX
-typedef struct
-{
-    DWORD dwPacketNumber;
-    XINPUT_GAMEPAD_EX Gamepad;
-} XINPUT_STATE_EX;
-#endif
 
+/* This is the same as XINPUT_BATTERY_INFORMATION, but always defined instead of just if WIN32_WINNT >= _WIN32_WINNT_WIN8 */
 typedef struct
 {
     BYTE BatteryType;
@@ -204,6 +188,12 @@ typedef struct
     SHORT sThumbRY;
 } XINPUT_GAMEPAD;
 
+typedef struct
+{
+    DWORD dwPacketNumber;
+    XINPUT_GAMEPAD Gamepad;
+} XINPUT_STATE;
+
 typedef struct
 {
     WORD wLeftMotorSpeed;
@@ -221,32 +211,46 @@ typedef struct
 
 #endif /* HAVE_XINPUT_H */
 
+/* This struct is not defined in XInput headers. */
+typedef struct _XINPUT_CAPABILITIES_EX
+{
+    XINPUT_CAPABILITIES Capabilities;
+    WORD VendorId;
+    WORD ProductId;
+    WORD ProductVersion;
+    WORD unk1;
+    DWORD unk2;
+} XINPUT_CAPABILITIES_EX, *PXINPUT_CAPABILITIES_EX;
+
 /* Forward decl's for XInput API's we load dynamically and use if available */
-typedef DWORD (WINAPI *XInputGetState_t)
-    (
-    DWORD         dwUserIndex,  /* [in] Index of the gamer associated with the device */
-    XINPUT_STATE_EX* pState     /* [out] Receives the current state */
-    );
+typedef DWORD(WINAPI *XInputGetState_t)(
+    DWORD dwUserIndex,      /* [in] Index of the gamer associated with the device */
+    XINPUT_STATE *pState    /* [out] Receives the current state */
+);
 
-typedef DWORD (WINAPI *XInputSetState_t)
-    (
-    DWORD             dwUserIndex,  /* [in] Index of the gamer associated with the device */
-    XINPUT_VIBRATION* pVibration    /* [in, out] The vibration information to send to the controller */
-    );
+typedef DWORD(WINAPI *XInputSetState_t)(
+    DWORD dwUserIndex,           /* [in] Index of the gamer associated with the device */
+    XINPUT_VIBRATION *pVibration /* [in, out] The vibration information to send to the controller */
+);
 
-typedef DWORD (WINAPI *XInputGetCapabilities_t)
-    (
-    DWORD                dwUserIndex,   /* [in] Index of the gamer associated with the device */
-    DWORD                dwFlags,       /* [in] Input flags that identify the device type */
-    XINPUT_CAPABILITIES* pCapabilities  /* [out] Receives the capabilities */
-    );
+typedef DWORD(WINAPI *XInputGetCapabilities_t)(
+    DWORD dwUserIndex,                 /* [in] Index of the gamer associated with the device */
+    DWORD dwFlags,                     /* [in] Input flags that identify the device type */
+    XINPUT_CAPABILITIES *pCapabilities /* [out] Receives the capabilities */
+);
 
-typedef DWORD (WINAPI *XInputGetBatteryInformation_t)
-    (
-    DWORD                         dwUserIndex,
-    BYTE                          devType,
-    XINPUT_BATTERY_INFORMATION_EX *pBatteryInformation
-    );
+/* Only available in XInput 1.4 that is shipped with Windows 8 and newer. */
+typedef DWORD(WINAPI *XInputGetCapabilitiesEx_t)(
+    DWORD dwReserved,                       /* [in] Must be 1 */
+    DWORD dwUserIndex,                      /* [in] Index of the gamer associated with the device */
+    DWORD dwFlags,                          /* [in] Input flags that identify the device type */
+    XINPUT_CAPABILITIES_EX *pCapabilitiesEx /* [out] Receives the capabilities */
+);
+
+typedef DWORD(WINAPI *XInputGetBatteryInformation_t)(
+    DWORD dwUserIndex,
+    BYTE devType,
+    XINPUT_BATTERY_INFORMATION_EX *pBatteryInformation);
 
 extern int WIN_LoadXInputDLL(void);
 extern void WIN_UnloadXInputDLL(void);
@@ -254,18 +258,20 @@ extern void WIN_UnloadXInputDLL(void);
 extern XInputGetState_t SDL_XInputGetState;
 extern XInputSetState_t SDL_XInputSetState;
 extern XInputGetCapabilities_t SDL_XInputGetCapabilities;
+extern XInputGetCapabilitiesEx_t SDL_XInputGetCapabilitiesEx;
 extern XInputGetBatteryInformation_t SDL_XInputGetBatteryInformation;
-extern DWORD SDL_XInputVersion;  /* ((major << 16) & 0xFF00) | (minor & 0xFF) */
+extern DWORD SDL_XInputVersion; /* ((major << 16) & 0xFF00) | (minor & 0xFF) */
 
 /* Ends C function definitions when using C++ */
 #ifdef __cplusplus
 }
 #endif
 
-#define XINPUTGETSTATE          SDL_XInputGetState
-#define XINPUTSETSTATE          SDL_XInputSetState
-#define XINPUTGETCAPABILITIES   SDL_XInputGetCapabilities
-#define XINPUTGETBATTERYINFORMATION   SDL_XInputGetBatteryInformation
+#define XINPUTGETSTATE              SDL_XInputGetState
+#define XINPUTSETSTATE              SDL_XInputSetState
+#define XINPUTGETCAPABILITIES       SDL_XInputGetCapabilities
+#define XINPUTGETCAPABILITIESEX     SDL_XInputGetCapabilitiesEx
+#define XINPUTGETBATTERYINFORMATION SDL_XInputGetBatteryInformation
 
 #endif /* SDL_xinput_h_ */
 
