@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2024 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -20,13 +20,6 @@
 */
 #include "../../SDL_internal.h"
 
-/* Standard C++11 includes */
-#include <functional>
-#include <string>
-#include <sstream>
-using namespace std;
-
-
 /* Windows includes */
 #include "ppltasks.h"
 using namespace concurrency;
@@ -40,11 +33,10 @@ using namespace Windows::System;
 using namespace Windows::UI::Core;
 using namespace Windows::UI::Input;
 
-#if WINAPI_FAMILY == WINAPI_FAMILY_PHONE_APP
+#if SDL_WINAPI_FAMILY_PHONE
 using namespace Windows::Phone::UI::Input;
 #endif
 
-
 /* SDL includes */
 extern "C" {
 #include "SDL_events.h"
@@ -53,7 +45,6 @@ extern "C" {
 #include "SDL_stdinc.h"
 #include "SDL_render.h"
 #include "../../video/SDL_sysvideo.h"
-//#include "../../SDL_hints_c.h"
 #include "../../events/SDL_events_c.h"
 #include "../../events/SDL_keyboard_c.h"
 #include "../../events/SDL_mouse_c.h"
@@ -67,20 +58,18 @@ extern "C" {
 #include "SDL_winrtapp_common.h"
 #include "SDL_winrtapp_direct3d.h"
 
-#if SDL_VIDEO_RENDER_D3D11 && !SDL_RENDER_DISABLED
+#if defined(SDL_VIDEO_RENDER_D3D11) && !defined(SDL_RENDER_DISABLED)
 /* Calling IDXGIDevice3::Trim on the active Direct3D 11.x device is necessary
  * when Windows 8.1 apps are about to get suspended.
  */
 extern "C" void D3D11_Trim(SDL_Renderer *);
 #endif
 
-
 // Compile-time debugging options:
 // To enable, uncomment; to disable, comment them out.
-//#define LOG_POINTER_EVENTS 1
-//#define LOG_WINDOW_EVENTS 1
-//#define LOG_ORIENTATION_EVENTS 1
-
+// #define LOG_POINTER_EVENTS 1
+// #define LOG_WINDOW_EVENTS 1
+// #define LOG_ORIENTATION_EVENTS 1
 
 // HACK, DLudwig: record a reference to the global, WinRT 'app'/view.
 // SDL/WinRT will use this throughout its code.
@@ -93,19 +82,18 @@ SDL_WinRTApp ^ SDL_WinRTGlobalApp = nullptr;
 
 ref class SDLApplicationSource sealed : Windows::ApplicationModel::Core::IFrameworkViewSource
 {
-public:
-    virtual Windows::ApplicationModel::Core::IFrameworkView^ CreateView();
+  public:
+    virtual Windows::ApplicationModel::Core::IFrameworkView ^ CreateView();
 };
 
-IFrameworkView^ SDLApplicationSource::CreateView()
+IFrameworkView ^ SDLApplicationSource::CreateView()
 {
     // TODO, WinRT: see if this function (CreateView) can ever get called
     // more than once.  For now, just prevent it from ever assigning
     // SDL_WinRTGlobalApp more than once.
     SDL_assert(!SDL_WinRTGlobalApp);
     SDL_WinRTApp ^ app = ref new SDL_WinRTApp();
-    if (!SDL_WinRTGlobalApp)
-    {
+    if (!SDL_WinRTGlobalApp) {
         SDL_WinRTGlobalApp = app;
     }
     return app;
@@ -119,21 +107,20 @@ int SDL_WinRTInitNonXAMLApp(int (*mainFunction)(int, char **))
     return 0;
 }
 
-static void
-WINRT_ProcessWindowSizeChange() // TODO: Pass an SDL_Window-identifying thing into WINRT_ProcessWindowSizeChange()
+static void WINRT_ProcessWindowSizeChange() // TODO: Pass an SDL_Window-identifying thing into WINRT_ProcessWindowSizeChange()
 {
     CoreWindow ^ coreWindow = CoreWindow::GetForCurrentThread();
     if (coreWindow) {
         if (WINRT_GlobalSDLWindow) {
-            SDL_Window * window = WINRT_GlobalSDLWindow;
-            SDL_WindowData * data = (SDL_WindowData *) window->driverdata;
+            SDL_Window *window = WINRT_GlobalSDLWindow;
+            SDL_WindowData *data = (SDL_WindowData *)window->driverdata;
 
             int x = WINRT_DIPS_TO_PHYSICAL_PIXELS(data->coreWindow->Bounds.Left);
             int y = WINRT_DIPS_TO_PHYSICAL_PIXELS(data->coreWindow->Bounds.Top);
             int w = WINRT_DIPS_TO_PHYSICAL_PIXELS(data->coreWindow->Bounds.Width);
             int h = WINRT_DIPS_TO_PHYSICAL_PIXELS(data->coreWindow->Bounds.Height);
 
-#if (WINAPI_FAMILY == WINAPI_FAMILY_PHONE_APP) && (NTDDI_VERSION == NTDDI_WIN8)
+#if SDL_WINAPI_FAMILY_PHONE && (NTDDI_VERSION == NTDDI_WIN8)
             /* WinPhone 8.0 always keeps its native window size in portrait,
                regardless of orientation.  This changes in WinPhone 8.1,
                in which the native window's size changes along with
@@ -145,12 +132,13 @@ WINRT_ProcessWindowSizeChange() // TODO: Pass an SDL_Window-identifying thing in
             */
             const DisplayOrientations currentOrientation = WINRT_DISPLAY_PROPERTY(CurrentOrientation);
             switch (currentOrientation) {
-                case DisplayOrientations::Landscape:
-                case DisplayOrientations::LandscapeFlipped: {
-                    int tmp = w;
-                    w = h;
-                    h = tmp;
-                } break;
+            case DisplayOrientations::Landscape:
+            case DisplayOrientations::LandscapeFlipped:
+            {
+                int tmp = w;
+                w = h;
+                h = tmp;
+            } break;
             }
 #endif
 
@@ -171,25 +159,24 @@ WINRT_ProcessWindowSizeChange() // TODO: Pass an SDL_Window-identifying thing in
     }
 }
 
-SDL_WinRTApp::SDL_WinRTApp() :
-    m_windowClosed(false),
-    m_windowVisible(true)
+SDL_WinRTApp::SDL_WinRTApp() : m_windowClosed(false),
+                               m_windowVisible(true)
 {
 }
 
-void SDL_WinRTApp::Initialize(CoreApplicationView^ applicationView)
+void SDL_WinRTApp::Initialize(CoreApplicationView ^ applicationView)
 {
     applicationView->Activated +=
-        ref new TypedEventHandler<CoreApplicationView^, IActivatedEventArgs^>(this, &SDL_WinRTApp::OnAppActivated);
+        ref new TypedEventHandler<CoreApplicationView ^, IActivatedEventArgs ^>(this, &SDL_WinRTApp::OnAppActivated);
 
     CoreApplication::Suspending +=
-        ref new EventHandler<SuspendingEventArgs^>(this, &SDL_WinRTApp::OnSuspending);
+        ref new EventHandler<SuspendingEventArgs ^>(this, &SDL_WinRTApp::OnSuspending);
 
     CoreApplication::Resuming +=
-        ref new EventHandler<Platform::Object^>(this, &SDL_WinRTApp::OnResuming);
+        ref new EventHandler<Platform::Object ^>(this, &SDL_WinRTApp::OnResuming);
 
     CoreApplication::Exiting +=
-        ref new EventHandler<Platform::Object^>(this, &SDL_WinRTApp::OnExiting);
+        ref new EventHandler<Platform::Object ^>(this, &SDL_WinRTApp::OnExiting);
 
 #if NTDDI_VERSION >= NTDDI_WIN10
     /* HACK ALERT!  Xbox One doesn't seem to detect gamepads unless something
@@ -198,44 +185,43 @@ void SDL_WinRTApp::Initialize(CoreApplicationView^ applicationView)
        sure that gamepad detection works later on, if requested.
     */
     Windows::Gaming::Input::Gamepad::GamepadAdded +=
-        ref new Windows::Foundation::EventHandler<Windows::Gaming::Input::Gamepad^>(
-            this, &SDL_WinRTApp::OnGamepadAdded
-        );
+        ref new Windows::Foundation::EventHandler<Windows::Gaming::Input::Gamepad ^>(
+            this, &SDL_WinRTApp::OnGamepadAdded);
 #endif
 }
 
 #if NTDDI_VERSION > NTDDI_WIN8
-void SDL_WinRTApp::OnOrientationChanged(DisplayInformation^ sender, Object^ args)
+void SDL_WinRTApp::OnOrientationChanged(DisplayInformation ^ sender, Object ^ args)
 #else
-void SDL_WinRTApp::OnOrientationChanged(Object^ sender)
+void SDL_WinRTApp::OnOrientationChanged(Object ^ sender)
 #endif
 {
-#if LOG_ORIENTATION_EVENTS==1
+#if LOG_ORIENTATION_EVENTS == 1
     {
-        CoreWindow^ window = CoreWindow::GetForCurrentThread();
+        CoreWindow ^ window = CoreWindow::GetForCurrentThread();
         if (window) {
             SDL_Log("%s, current orientation=%d, native orientation=%d, auto rot. pref=%d, CoreWindow Bounds={%f,%f,%f,%f}\n",
-                __FUNCTION__,
-                WINRT_DISPLAY_PROPERTY(CurrentOrientation),
-                WINRT_DISPLAY_PROPERTY(NativeOrientation),
-                WINRT_DISPLAY_PROPERTY(AutoRotationPreferences),
-                window->Bounds.X,
-                window->Bounds.Y,
-                window->Bounds.Width,
-                window->Bounds.Height);
+                    __FUNCTION__,
+                    WINRT_DISPLAY_PROPERTY(CurrentOrientation),
+                    WINRT_DISPLAY_PROPERTY(NativeOrientation),
+                    WINRT_DISPLAY_PROPERTY(AutoRotationPreferences),
+                    window->Bounds.X,
+                    window->Bounds.Y,
+                    window->Bounds.Width,
+                    window->Bounds.Height);
         } else {
             SDL_Log("%s, current orientation=%d, native orientation=%d, auto rot. pref=%d\n",
-                __FUNCTION__,
-                WINRT_DISPLAY_PROPERTY(CurrentOrientation),
-                WINRT_DISPLAY_PROPERTY(NativeOrientation),
-                WINRT_DISPLAY_PROPERTY(AutoRotationPreferences));
+                    __FUNCTION__,
+                    WINRT_DISPLAY_PROPERTY(CurrentOrientation),
+                    WINRT_DISPLAY_PROPERTY(NativeOrientation),
+                    WINRT_DISPLAY_PROPERTY(AutoRotationPreferences));
         }
     }
 #endif
 
     WINRT_ProcessWindowSizeChange();
 
-#if WINAPI_FAMILY == WINAPI_FAMILY_PHONE_APP
+#if SDL_WINAPI_FAMILY_PHONE
     // HACK: Make sure that orientation changes
     // lead to the Direct3D renderer's viewport getting updated:
     //
@@ -245,116 +231,113 @@ void SDL_WinRTApp::OnOrientationChanged(Object^ sender)
     // I'm not currently sure why this is, but it seems to work fine. -- David L.
     //
     // TODO, WinRT: do more extensive research into why orientation changes on Win 8.x don't need D3D changes, or if they might, in some cases
-    SDL_Window * window = WINRT_GlobalSDLWindow;
+    SDL_Window *window = WINRT_GlobalSDLWindow;
     if (window) {
-        SDL_WindowData * data = (SDL_WindowData *)window->driverdata;
+        SDL_WindowData *data = (SDL_WindowData *)window->driverdata;
         int w = WINRT_DIPS_TO_PHYSICAL_PIXELS(data->coreWindow->Bounds.Width);
         int h = WINRT_DIPS_TO_PHYSICAL_PIXELS(data->coreWindow->Bounds.Height);
         SDL_SendWindowEvent(WINRT_GlobalSDLWindow, SDL_WINDOWEVENT_SIZE_CHANGED, w, h);
     }
 #endif
-
 }
 
-void SDL_WinRTApp::SetWindow(CoreWindow^ window)
+void SDL_WinRTApp::SetWindow(CoreWindow ^ window)
 {
-#if LOG_WINDOW_EVENTS==1
+#if LOG_WINDOW_EVENTS == 1
     SDL_Log("%s, current orientation=%d, native orientation=%d, auto rot. pref=%d, window bounds={%f, %f, %f,%f}\n",
-        __FUNCTION__,
-        WINRT_DISPLAY_PROPERTY(CurrentOrientation),
-        WINRT_DISPLAY_PROPERTY(NativeOrientation),
-        WINRT_DISPLAY_PROPERTY(AutoRotationPreferences),
-        window->Bounds.X,
-        window->Bounds.Y,
-        window->Bounds.Width,
-        window->Bounds.Height);
+            __FUNCTION__,
+            WINRT_DISPLAY_PROPERTY(CurrentOrientation),
+            WINRT_DISPLAY_PROPERTY(NativeOrientation),
+            WINRT_DISPLAY_PROPERTY(AutoRotationPreferences),
+            window->Bounds.X,
+            window->Bounds.Y,
+            window->Bounds.Width,
+            window->Bounds.Height);
 #endif
 
-    window->SizeChanged += 
-        ref new TypedEventHandler<CoreWindow^, WindowSizeChangedEventArgs^>(this, &SDL_WinRTApp::OnWindowSizeChanged);
+    window->SizeChanged +=
+        ref new TypedEventHandler<CoreWindow ^, WindowSizeChangedEventArgs ^>(this, &SDL_WinRTApp::OnWindowSizeChanged);
 
     window->VisibilityChanged +=
-        ref new TypedEventHandler<CoreWindow^, VisibilityChangedEventArgs^>(this, &SDL_WinRTApp::OnVisibilityChanged);
+        ref new TypedEventHandler<CoreWindow ^, VisibilityChangedEventArgs ^>(this, &SDL_WinRTApp::OnVisibilityChanged);
 
     window->Activated +=
-        ref new TypedEventHandler<CoreWindow^, WindowActivatedEventArgs^>(this, &SDL_WinRTApp::OnWindowActivated);
+        ref new TypedEventHandler<CoreWindow ^, WindowActivatedEventArgs ^>(this, &SDL_WinRTApp::OnWindowActivated);
 
-    window->Closed += 
-        ref new TypedEventHandler<CoreWindow^, CoreWindowEventArgs^>(this, &SDL_WinRTApp::OnWindowClosed);
+    window->Closed +=
+        ref new TypedEventHandler<CoreWindow ^, CoreWindowEventArgs ^>(this, &SDL_WinRTApp::OnWindowClosed);
 
-#if WINAPI_FAMILY != WINAPI_FAMILY_PHONE_APP
+#if !SDL_WINAPI_FAMILY_PHONE
     window->PointerCursor = ref new CoreCursor(CoreCursorType::Arrow, 0);
 #endif
 
     window->PointerPressed +=
-        ref new TypedEventHandler<CoreWindow^, PointerEventArgs^>(this, &SDL_WinRTApp::OnPointerPressed);
+        ref new TypedEventHandler<CoreWindow ^, PointerEventArgs ^>(this, &SDL_WinRTApp::OnPointerPressed);
 
     window->PointerMoved +=
-        ref new TypedEventHandler<CoreWindow^, PointerEventArgs^>(this, &SDL_WinRTApp::OnPointerMoved);
+        ref new TypedEventHandler<CoreWindow ^, PointerEventArgs ^>(this, &SDL_WinRTApp::OnPointerMoved);
 
     window->PointerReleased +=
-        ref new TypedEventHandler<CoreWindow^, PointerEventArgs^>(this, &SDL_WinRTApp::OnPointerReleased);
+        ref new TypedEventHandler<CoreWindow ^, PointerEventArgs ^>(this, &SDL_WinRTApp::OnPointerReleased);
 
     window->PointerEntered +=
-        ref new TypedEventHandler<CoreWindow^, PointerEventArgs^>(this, &SDL_WinRTApp::OnPointerEntered);
+        ref new TypedEventHandler<CoreWindow ^, PointerEventArgs ^>(this, &SDL_WinRTApp::OnPointerEntered);
 
     window->PointerExited +=
-        ref new TypedEventHandler<CoreWindow^, PointerEventArgs^>(this, &SDL_WinRTApp::OnPointerExited);
+        ref new TypedEventHandler<CoreWindow ^, PointerEventArgs ^>(this, &SDL_WinRTApp::OnPointerExited);
 
     window->PointerWheelChanged +=
-        ref new TypedEventHandler<CoreWindow^, PointerEventArgs^>(this, &SDL_WinRTApp::OnPointerWheelChanged);
+        ref new TypedEventHandler<CoreWindow ^, PointerEventArgs ^>(this, &SDL_WinRTApp::OnPointerWheelChanged);
 
-#if WINAPI_FAMILY != WINAPI_FAMILY_PHONE_APP
+#if !SDL_WINAPI_FAMILY_PHONE
     // Retrieves relative-only mouse movements:
     Windows::Devices::Input::MouseDevice::GetForCurrentView()->MouseMoved +=
-        ref new TypedEventHandler<MouseDevice^, MouseEventArgs^>(this, &SDL_WinRTApp::OnMouseMoved);
+        ref new TypedEventHandler<MouseDevice ^, MouseEventArgs ^>(this, &SDL_WinRTApp::OnMouseMoved);
 #endif
 
     window->KeyDown +=
-        ref new TypedEventHandler<CoreWindow^, KeyEventArgs^>(this, &SDL_WinRTApp::OnKeyDown);
+        ref new TypedEventHandler<CoreWindow ^, KeyEventArgs ^>(this, &SDL_WinRTApp::OnKeyDown);
 
     window->KeyUp +=
-        ref new TypedEventHandler<CoreWindow^, KeyEventArgs^>(this, &SDL_WinRTApp::OnKeyUp);
+        ref new TypedEventHandler<CoreWindow ^, KeyEventArgs ^>(this, &SDL_WinRTApp::OnKeyUp);
 
     window->CharacterReceived +=
-        ref new TypedEventHandler<CoreWindow^, CharacterReceivedEventArgs^>(this, &SDL_WinRTApp::OnCharacterReceived);
+        ref new TypedEventHandler<CoreWindow ^, CharacterReceivedEventArgs ^>(this, &SDL_WinRTApp::OnCharacterReceived);
 
 #if NTDDI_VERSION >= NTDDI_WIN10
     Windows::UI::Core::SystemNavigationManager::GetForCurrentView()->BackRequested +=
-        ref new EventHandler<BackRequestedEventArgs^>(this, &SDL_WinRTApp::OnBackButtonPressed);
-#elif WINAPI_FAMILY == WINAPI_FAMILY_PHONE_APP
+        ref new EventHandler<BackRequestedEventArgs ^>(this, &SDL_WinRTApp::OnBackButtonPressed);
+#elif SDL_WINAPI_FAMILY_PHONE
     HardwareButtons::BackPressed +=
-        ref new EventHandler<BackPressedEventArgs^>(this, &SDL_WinRTApp::OnBackButtonPressed);
+        ref new EventHandler<BackPressedEventArgs ^>(this, &SDL_WinRTApp::OnBackButtonPressed);
 #endif
 
 #if NTDDI_VERSION > NTDDI_WIN8
     DisplayInformation::GetForCurrentView()->OrientationChanged +=
-        ref new TypedEventHandler<Windows::Graphics::Display::DisplayInformation^, Object^>(this, &SDL_WinRTApp::OnOrientationChanged);
+        ref new TypedEventHandler<Windows::Graphics::Display::DisplayInformation ^, Object ^>(this, &SDL_WinRTApp::OnOrientationChanged);
 #else
     DisplayProperties::OrientationChanged +=
         ref new DisplayPropertiesEventHandler(this, &SDL_WinRTApp::OnOrientationChanged);
 #endif
 
-#if (WINAPI_FAMILY == WINAPI_FAMILY_APP) && (NTDDI_VERSION < NTDDI_WIN10)  // for Windows 8/8.1/RT apps... (and not Phone apps)
+#if (WINAPI_FAMILY == WINAPI_FAMILY_APP) && (NTDDI_VERSION < NTDDI_WIN10) // for Windows 8/8.1/RT apps... (and not Phone apps)
     // Make sure we know when a user has opened the app's settings pane.
     // This is needed in order to display a privacy policy, which needs
     // to be done for network-enabled apps, as per Windows Store requirements.
     using namespace Windows::UI::ApplicationSettings;
     SettingsPane::GetForCurrentView()->CommandsRequested +=
-        ref new TypedEventHandler<SettingsPane^, SettingsPaneCommandsRequestedEventArgs^>
-            (this, &SDL_WinRTApp::OnSettingsPaneCommandsRequested);
+        ref new TypedEventHandler<SettingsPane ^, SettingsPaneCommandsRequestedEventArgs ^>(this, &SDL_WinRTApp::OnSettingsPaneCommandsRequested);
 #endif
 }
 
-void SDL_WinRTApp::Load(Platform::String^ entryPoint)
+void SDL_WinRTApp::Load(Platform::String ^ entryPoint)
 {
 }
 
 void SDL_WinRTApp::Run()
 {
     SDL_SetMainReady();
-    if (WINRT_SDLAppEntryPoint)
-    {
+    if (WINRT_SDLAppEntryPoint) {
         // TODO, WinRT: pass the C-style main() a reasonably realistic
         // representation of command line arguments.
         int argc = 1;
@@ -373,7 +356,7 @@ void SDL_WinRTApp::Run()
 static bool IsSDLWindowEventPending(SDL_WindowEventID windowEventID)
 {
     SDL_Event events[128];
-    const int count = SDL_PeepEvents(events, sizeof(events)/sizeof(SDL_Event), SDL_PEEKEVENT, SDL_WINDOWEVENT, SDL_WINDOWEVENT);
+    const int count = SDL_PeepEvents(events, sizeof(events) / sizeof(SDL_Event), SDL_PEEKEVENT, SDL_WINDOWEVENT, SDL_WINDOWEVENT);
     for (int i = 0; i < count; ++i) {
         if (events[i].window.event == windowEventID) {
             return true;
@@ -388,7 +371,7 @@ bool SDL_WinRTApp::ShouldWaitForAppResumeEvents()
     if (m_windowVisible) {
         return false;
     }
-    
+
     /* Don't wait until the window-hide events finish processing.
      * Do note that if an app-suspend event is sent (as indicated
      * by SDL_APP_WILLENTERBACKGROUND and SDL_APP_DIDENTERBACKGROUND
@@ -437,17 +420,17 @@ void SDL_WinRTApp::Uninitialize()
 
 #if (WINAPI_FAMILY == WINAPI_FAMILY_APP) && (NTDDI_VERSION < NTDDI_WIN10)
 void SDL_WinRTApp::OnSettingsPaneCommandsRequested(
-    Windows::UI::ApplicationSettings::SettingsPane ^p,
-    Windows::UI::ApplicationSettings::SettingsPaneCommandsRequestedEventArgs ^args)
+    Windows::UI::ApplicationSettings::SettingsPane ^ p,
+    Windows::UI::ApplicationSettings::SettingsPaneCommandsRequestedEventArgs ^ args)
 {
     using namespace Platform;
     using namespace Windows::UI::ApplicationSettings;
     using namespace Windows::UI::Popups;
 
-    String ^privacyPolicyURL = nullptr;     // a URL to an app's Privacy Policy
-    String ^privacyPolicyLabel = nullptr;   // label/link text
-    const char *tmpHintValue = NULL;        // SDL_GetHint-retrieved value, used immediately
-    wchar_t *tmpStr = NULL;                 // used for UTF8 to UCS2 conversion
+    String ^ privacyPolicyURL = nullptr;   // a URL to an app's Privacy Policy
+    String ^ privacyPolicyLabel = nullptr; // label/link text
+    const char *tmpHintValue = NULL;       // SDL_GetHint-retrieved value, used immediately
+    wchar_t *tmpStr = NULL;                // used for UTF8 to UCS2 conversion
 
     // Setup a 'Privacy Policy' link, if one is available (via SDL_GetHint):
     tmpHintValue = SDL_GetHint(SDL_HINT_WINRT_PRIVACY_POLICY_URL);
@@ -471,39 +454,39 @@ void SDL_WinRTApp::OnSettingsPaneCommandsRequested(
         // Register the link, along with a handler to be called if and when it is
         // clicked:
         auto cmd = ref new SettingsCommand(L"privacyPolicy", privacyPolicyLabel,
-            ref new UICommandInvokedHandler([=](IUICommand ^) {
-                Windows::System::Launcher::LaunchUriAsync(ref new Uri(privacyPolicyURL));
-        }));
+                                           ref new UICommandInvokedHandler([=](IUICommand ^) {
+                                               Windows::System::Launcher::LaunchUriAsync(ref new Uri(privacyPolicyURL));
+                                           }));
         args->Request->ApplicationCommands->Append(cmd);
     }
 }
 #endif // if (WINAPI_FAMILY == WINAPI_FAMILY_APP) && (NTDDI_VERSION < NTDDI_WIN10)
 
-void SDL_WinRTApp::OnWindowSizeChanged(CoreWindow^ sender, WindowSizeChangedEventArgs^ args)
+void SDL_WinRTApp::OnWindowSizeChanged(CoreWindow ^ sender, WindowSizeChangedEventArgs ^ args)
 {
-#if LOG_WINDOW_EVENTS==1
+#if LOG_WINDOW_EVENTS == 1
     SDL_Log("%s, size={%f,%f}, bounds={%f,%f,%f,%f}, current orientation=%d, native orientation=%d, auto rot. pref=%d, WINRT_GlobalSDLWindow?=%s\n",
-        __FUNCTION__,
-        args->Size.Width, args->Size.Height,
-        sender->Bounds.X, sender->Bounds.Y, sender->Bounds.Width, sender->Bounds.Height,
-        WINRT_DISPLAY_PROPERTY(CurrentOrientation),
-        WINRT_DISPLAY_PROPERTY(NativeOrientation),
-        WINRT_DISPLAY_PROPERTY(AutoRotationPreferences),
-        (WINRT_GlobalSDLWindow ? "yes" : "no"));
+            __FUNCTION__,
+            args->Size.Width, args->Size.Height,
+            sender->Bounds.X, sender->Bounds.Y, sender->Bounds.Width, sender->Bounds.Height,
+            WINRT_DISPLAY_PROPERTY(CurrentOrientation),
+            WINRT_DISPLAY_PROPERTY(NativeOrientation),
+            WINRT_DISPLAY_PROPERTY(AutoRotationPreferences),
+            (WINRT_GlobalSDLWindow ? "yes" : "no"));
 #endif
 
     WINRT_ProcessWindowSizeChange();
 }
 
-void SDL_WinRTApp::OnVisibilityChanged(CoreWindow^ sender, VisibilityChangedEventArgs^ args)
+void SDL_WinRTApp::OnVisibilityChanged(CoreWindow ^ sender, VisibilityChangedEventArgs ^ args)
 {
-#if LOG_WINDOW_EVENTS==1
+#if LOG_WINDOW_EVENTS == 1
     SDL_Log("%s, visible?=%s, bounds={%f,%f,%f,%f}, WINRT_GlobalSDLWindow?=%s\n",
-        __FUNCTION__,
-        (args->Visible ? "yes" : "no"),
-        sender->Bounds.X, sender->Bounds.Y,
-        sender->Bounds.Width, sender->Bounds.Height,
-        (WINRT_GlobalSDLWindow ? "yes" : "no"));
+            __FUNCTION__,
+            (args->Visible ? "yes" : "no"),
+            sender->Bounds.X, sender->Bounds.Y,
+            sender->Bounds.Width, sender->Bounds.Height,
+            (WINRT_GlobalSDLWindow ? "yes" : "no"));
 #endif
 
     m_windowVisible = args->Visible;
@@ -534,12 +517,12 @@ void SDL_WinRTApp::OnVisibilityChanged(CoreWindow^ sender, VisibilityChangedEven
     }
 }
 
-void SDL_WinRTApp::OnWindowActivated(CoreWindow^ sender, WindowActivatedEventArgs^ args)
+void SDL_WinRTApp::OnWindowActivated(CoreWindow ^ sender, WindowActivatedEventArgs ^ args)
 {
-#if LOG_WINDOW_EVENTS==1
+#if LOG_WINDOW_EVENTS == 1
     SDL_Log("%s, WINRT_GlobalSDLWindow?=%s\n\n",
-        __FUNCTION__,
-        (WINRT_GlobalSDLWindow ? "yes" : "no"));
+            __FUNCTION__,
+            (WINRT_GlobalSDLWindow ? "yes" : "no"));
 #endif
 
     /* There's no property in Win 8.x to tell whether a window is active or
@@ -549,14 +532,14 @@ void SDL_WinRTApp::OnWindowActivated(CoreWindow^ sender, WindowActivatedEventArg
     */
     sender->CustomProperties->Insert("SDLHelperWindowActivationState", args->WindowActivationState);
 
-    SDL_Window * window = WINRT_GlobalSDLWindow;
+    SDL_Window *window = WINRT_GlobalSDLWindow;
     if (window) {
         if (args->WindowActivationState != CoreWindowActivationState::Deactivated) {
             SDL_SendWindowEvent(window, SDL_WINDOWEVENT_SHOWN, 0, 0);
             if (SDL_GetKeyboardFocus() != window) {
                 SDL_SetKeyboardFocus(window);
             }
-        
+
             /* Send a mouse-motion event as appropriate.
                This doesn't work when called from OnPointerEntered, at least
                not in WinRT CoreWindow apps (as OnPointerEntered doesn't
@@ -566,19 +549,19 @@ void SDL_WinRTApp::OnWindowActivated(CoreWindow^ sender, WindowActivatedEventArg
                Don't do it on WinPhone 8.0 though, as CoreWindow's 'PointerPosition'
                property isn't available.
              */
-#if (WINAPI_FAMILY != WINAPI_FAMILY_PHONE_APP) || (NTDDI_VERSION >= NTDDI_WINBLUE)
+#if !SDL_WINAPI_FAMILY_PHONE || (NTDDI_VERSION >= NTDDI_WINBLUE)
             Point cursorPos = WINRT_TransformCursorPosition(window, sender->PointerPosition, TransformToSDLWindowSize);
             SDL_SendMouseMotion(window, 0, 0, (int)cursorPos.X, (int)cursorPos.Y);
 #endif
 
             /* TODO, WinRT: see if the Win32 bugfix from https://hg.libsdl.org/SDL/rev/d278747da408 needs to be applied (on window activation) */
-            //WIN_CheckAsyncMouseRelease(data);
+            // WIN_CheckAsyncMouseRelease(data);
 
             /* TODO, WinRT: implement clipboard support, if possible */
             ///*
             // * FIXME: Update keyboard state
             // */
-            //WIN_CheckClipboardUpdate(data->videodata);
+            // WIN_CheckClipboardUpdate(data->videodata);
 
             // HACK: Resetting the mouse-cursor here seems to fix
             // https://bugzilla.libsdl.org/show_bug.cgi?id=3217, whereby a
@@ -596,20 +579,20 @@ void SDL_WinRTApp::OnWindowActivated(CoreWindow^ sender, WindowActivatedEventArg
     }
 }
 
-void SDL_WinRTApp::OnWindowClosed(CoreWindow^ sender, CoreWindowEventArgs^ args)
+void SDL_WinRTApp::OnWindowClosed(CoreWindow ^ sender, CoreWindowEventArgs ^ args)
 {
-#if LOG_WINDOW_EVENTS==1
+#if LOG_WINDOW_EVENTS == 1
     SDL_Log("%s\n", __FUNCTION__);
 #endif
     m_windowClosed = true;
 }
 
-void SDL_WinRTApp::OnAppActivated(CoreApplicationView^ applicationView, IActivatedEventArgs^ args)
+void SDL_WinRTApp::OnAppActivated(CoreApplicationView ^ applicationView, IActivatedEventArgs ^ args)
 {
     CoreWindow::GetForCurrentThread()->Activate();
 }
 
-void SDL_WinRTApp::OnSuspending(Platform::Object^ sender, SuspendingEventArgs^ args)
+void SDL_WinRTApp::OnSuspending(Platform::Object ^ sender, SuspendingEventArgs ^ args)
 {
     // Save app state asynchronously after requesting a deferral. Holding a deferral
     // indicates that the application is busy performing suspending operations. Be
@@ -625,9 +608,8 @@ void SDL_WinRTApp::OnSuspending(Platform::Object^ sender, SuspendingEventArgs^ a
     // this could be important.
     SDL_SendAppEvent(SDL_APP_WILLENTERBACKGROUND);
 
-    SuspendingDeferral^ deferral = args->SuspendingOperation->GetDeferral();
-    create_task([this, deferral]()
-    {
+    SuspendingDeferral ^ deferral = args->SuspendingOperation->GetDeferral();
+    create_task([this, deferral]() {
         // Send an app did-enter-background event immediately to observers.
         // CoreDispatcher::ProcessEvents, which is the backbone on which
         // SDL_WinRTApp::PumpEvents is built, will not return to its caller
@@ -640,9 +622,9 @@ void SDL_WinRTApp::OnSuspending(Platform::Object^ sender, SuspendingEventArgs^ a
         // Let the Direct3D 11 renderer prepare for the app to be backgrounded.
         // This is necessary for Windows 8.1, possibly elsewhere in the future.
         // More details at: http://msdn.microsoft.com/en-us/library/windows/apps/Hh994929.aspx
-#if SDL_VIDEO_RENDER_D3D11 && !SDL_RENDER_DISABLED
+#if defined(SDL_VIDEO_RENDER_D3D11) && !defined(SDL_RENDER_DISABLED)
         if (WINRT_GlobalSDLWindow) {
-            SDL_Renderer * renderer = SDL_GetRenderer(WINRT_GlobalSDLWindow);
+            SDL_Renderer *renderer = SDL_GetRenderer(WINRT_GlobalSDLWindow);
             if (renderer && (SDL_strcmp(renderer->info.name, "direct3d11") == 0)) {
                 D3D11_Trim(renderer);
             }
@@ -653,7 +635,7 @@ void SDL_WinRTApp::OnSuspending(Platform::Object^ sender, SuspendingEventArgs^ a
     });
 }
 
-void SDL_WinRTApp::OnResuming(Platform::Object^ sender, Platform::Object^ args)
+void SDL_WinRTApp::OnResuming(Platform::Object ^ sender, Platform::Object ^ args)
 {
     // Restore any data or state that was unloaded on suspend. By default, data
     // and state are persisted when resuming from suspend. Note that these events
@@ -662,29 +644,28 @@ void SDL_WinRTApp::OnResuming(Platform::Object^ sender, Platform::Object^ args)
     SDL_SendAppEvent(SDL_APP_DIDENTERFOREGROUND);
 }
 
-void SDL_WinRTApp::OnExiting(Platform::Object^ sender, Platform::Object^ args)
+void SDL_WinRTApp::OnExiting(Platform::Object ^ sender, Platform::Object ^ args)
 {
     SDL_SendAppEvent(SDL_APP_TERMINATING);
 }
 
-static void
-WINRT_LogPointerEvent(const char * header, Windows::UI::Core::PointerEventArgs ^ args, Windows::Foundation::Point transformedPoint)
+static void WINRT_LogPointerEvent(const char *header, Windows::UI::Core::PointerEventArgs ^ args, Windows::Foundation::Point transformedPoint)
 {
     Uint8 button, pressed;
     Windows::UI::Input::PointerPoint ^ pt = args->CurrentPoint;
     WINRT_GetSDLButtonForPointerPoint(pt, &button, &pressed);
     SDL_Log("%s: Position={%f,%f}, Transformed Pos={%f, %f}, MouseWheelDelta=%d, FrameId=%d, PointerId=%d, SDL button=%d pressed=%d\n",
-        header,
-        pt->Position.X, pt->Position.Y,
-        transformedPoint.X, transformedPoint.Y,
-        pt->Properties->MouseWheelDelta,
-        pt->FrameId,
-        pt->PointerId,
-        button,
-        pressed);
+            header,
+            pt->Position.X, pt->Position.Y,
+            transformedPoint.X, transformedPoint.Y,
+            pt->Properties->MouseWheelDelta,
+            pt->FrameId,
+            pt->PointerId,
+            button,
+            pressed);
 }
 
-void SDL_WinRTApp::OnPointerPressed(CoreWindow^ sender, PointerEventArgs^ args)
+void SDL_WinRTApp::OnPointerPressed(CoreWindow ^ sender, PointerEventArgs ^ args)
 {
 #if LOG_POINTER_EVENTS
     WINRT_LogPointerEvent("pointer pressed", args, WINRT_TransformCursorPosition(WINRT_GlobalSDLWindow, args->CurrentPoint->Position, TransformToSDLWindowSize));
@@ -693,7 +674,7 @@ void SDL_WinRTApp::OnPointerPressed(CoreWindow^ sender, PointerEventArgs^ args)
     WINRT_ProcessPointerPressedEvent(WINRT_GlobalSDLWindow, args->CurrentPoint);
 }
 
-void SDL_WinRTApp::OnPointerMoved(CoreWindow^ sender, PointerEventArgs^ args)
+void SDL_WinRTApp::OnPointerMoved(CoreWindow ^ sender, PointerEventArgs ^ args)
 {
 #if LOG_POINTER_EVENTS
     WINRT_LogPointerEvent("pointer moved", args, WINRT_TransformCursorPosition(WINRT_GlobalSDLWindow, args->CurrentPoint->Position, TransformToSDLWindowSize));
@@ -702,16 +683,16 @@ void SDL_WinRTApp::OnPointerMoved(CoreWindow^ sender, PointerEventArgs^ args)
     WINRT_ProcessPointerMovedEvent(WINRT_GlobalSDLWindow, args->CurrentPoint);
 }
 
-void SDL_WinRTApp::OnPointerReleased(CoreWindow^ sender, PointerEventArgs^ args)
+void SDL_WinRTApp::OnPointerReleased(CoreWindow ^ sender, PointerEventArgs ^ args)
 {
 #if LOG_POINTER_EVENTS
     WINRT_LogPointerEvent("pointer released", args, WINRT_TransformCursorPosition(WINRT_GlobalSDLWindow, args->CurrentPoint->Position, TransformToSDLWindowSize));
 #endif
-    
+
     WINRT_ProcessPointerReleasedEvent(WINRT_GlobalSDLWindow, args->CurrentPoint);
 }
 
-void SDL_WinRTApp::OnPointerEntered(CoreWindow^ sender, PointerEventArgs^ args)
+void SDL_WinRTApp::OnPointerEntered(CoreWindow ^ sender, PointerEventArgs ^ args)
 {
 #if LOG_POINTER_EVENTS
     WINRT_LogPointerEvent("pointer entered", args, WINRT_TransformCursorPosition(WINRT_GlobalSDLWindow, args->CurrentPoint->Position, TransformToSDLWindowSize));
@@ -720,7 +701,7 @@ void SDL_WinRTApp::OnPointerEntered(CoreWindow^ sender, PointerEventArgs^ args)
     WINRT_ProcessPointerEnteredEvent(WINRT_GlobalSDLWindow, args->CurrentPoint);
 }
 
-void SDL_WinRTApp::OnPointerExited(CoreWindow^ sender, PointerEventArgs^ args)
+void SDL_WinRTApp::OnPointerExited(CoreWindow ^ sender, PointerEventArgs ^ args)
 {
 #if LOG_POINTER_EVENTS
     WINRT_LogPointerEvent("pointer exited", args, WINRT_TransformCursorPosition(WINRT_GlobalSDLWindow, args->CurrentPoint->Position, TransformToSDLWindowSize));
@@ -729,7 +710,7 @@ void SDL_WinRTApp::OnPointerExited(CoreWindow^ sender, PointerEventArgs^ args)
     WINRT_ProcessPointerExitedEvent(WINRT_GlobalSDLWindow, args->CurrentPoint);
 }
 
-void SDL_WinRTApp::OnPointerWheelChanged(CoreWindow^ sender, PointerEventArgs^ args)
+void SDL_WinRTApp::OnPointerWheelChanged(CoreWindow ^ sender, PointerEventArgs ^ args)
 {
 #if LOG_POINTER_EVENTS
     WINRT_LogPointerEvent("pointer wheel changed", args, WINRT_TransformCursorPosition(WINRT_GlobalSDLWindow, args->CurrentPoint->Position, TransformToSDLWindowSize));
@@ -738,22 +719,22 @@ void SDL_WinRTApp::OnPointerWheelChanged(CoreWindow^ sender, PointerEventArgs^ a
     WINRT_ProcessPointerWheelChangedEvent(WINRT_GlobalSDLWindow, args->CurrentPoint);
 }
 
-void SDL_WinRTApp::OnMouseMoved(MouseDevice^ mouseDevice, MouseEventArgs^ args)
+void SDL_WinRTApp::OnMouseMoved(MouseDevice ^ mouseDevice, MouseEventArgs ^ args)
 {
     WINRT_ProcessMouseMovedEvent(WINRT_GlobalSDLWindow, args);
 }
 
-void SDL_WinRTApp::OnKeyDown(Windows::UI::Core::CoreWindow^ sender, Windows::UI::Core::KeyEventArgs^ args)
+void SDL_WinRTApp::OnKeyDown(Windows::UI::Core::CoreWindow ^ sender, Windows::UI::Core::KeyEventArgs ^ args)
 {
     WINRT_ProcessKeyDownEvent(args);
 }
 
-void SDL_WinRTApp::OnKeyUp(Windows::UI::Core::CoreWindow^ sender, Windows::UI::Core::KeyEventArgs^ args)
+void SDL_WinRTApp::OnKeyUp(Windows::UI::Core::CoreWindow ^ sender, Windows::UI::Core::KeyEventArgs ^ args)
 {
     WINRT_ProcessKeyUpEvent(args);
 }
 
-void SDL_WinRTApp::OnCharacterReceived(Windows::UI::Core::CoreWindow^ sender, Windows::UI::Core::CharacterReceivedEventArgs^ args)
+void SDL_WinRTApp::OnCharacterReceived(Windows::UI::Core::CoreWindow ^ sender, Windows::UI::Core::CharacterReceivedEventArgs ^ args)
 {
     WINRT_ProcessCharacterReceivedEvent(args);
 }
@@ -770,13 +751,13 @@ static void WINRT_OnBackButtonPressed(BackButtonEventArgs ^ args)
 }
 
 #if NTDDI_VERSION >= NTDDI_WIN10
-void SDL_WinRTApp::OnBackButtonPressed(Platform::Object^ sender, Windows::UI::Core::BackRequestedEventArgs^ args)
+void SDL_WinRTApp::OnBackButtonPressed(Platform::Object ^ sender, Windows::UI::Core::BackRequestedEventArgs ^ args)
 
 {
     WINRT_OnBackButtonPressed(args);
 }
-#elif WINAPI_FAMILY == WINAPI_FAMILY_PHONE_APP
-void SDL_WinRTApp::OnBackButtonPressed(Platform::Object^ sender, Windows::Phone::UI::Input::BackPressedEventArgs^ args)
+#elif SDL_WINAPI_FAMILY_PHONE
+void SDL_WinRTApp::OnBackButtonPressed(Platform::Object ^ sender, Windows::Phone::UI::Input::BackPressedEventArgs ^ args)
 
 {
     WINRT_OnBackButtonPressed(args);
@@ -784,7 +765,7 @@ void SDL_WinRTApp::OnBackButtonPressed(Platform::Object^ sender, Windows::Phone:
 #endif
 
 #if NTDDI_VERSION >= NTDDI_WIN10
-void SDL_WinRTApp::OnGamepadAdded(Platform::Object ^sender, Windows::Gaming::Input::Gamepad ^gamepad)
+void SDL_WinRTApp::OnGamepadAdded(Platform::Object ^ sender, Windows::Gaming::Input::Gamepad ^ gamepad)
 {
     /* HACK ALERT: Nothing needs to be done here, as this method currently
        only exists to allow something to be registered with Win10's
