@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2024 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -44,9 +44,7 @@ static SDL_hapticlist_item *SDL_hapticlist = NULL;
 static SDL_hapticlist_item *SDL_hapticlist_tail = NULL;
 static int numhaptics = 0;
 
-
-int
-SDL_SYS_HapticInit(void)
+int SDL_SYS_HapticInit(void)
 {
     /* Support for device connect/disconnect is API >= 16 only,
      * so we poll every three seconds
@@ -57,17 +55,15 @@ SDL_SYS_HapticInit(void)
         timeout = SDL_GetTicks() + 3000;
         Android_JNI_PollHapticDevices();
     }
-    return (numhaptics);
+    return numhaptics;
 }
 
-int
-SDL_SYS_NumHaptics(void)
+int SDL_SYS_NumHaptics(void)
 {
-    return (numhaptics);
+    return numhaptics;
 }
 
-static SDL_hapticlist_item *
-HapticByOrder(int index)
+static SDL_hapticlist_item *HapticByOrder(int index)
 {
     SDL_hapticlist_item *item = SDL_hapticlist;
     if ((index < 0) || (index >= numhaptics)) {
@@ -81,11 +77,10 @@ HapticByOrder(int index)
     return item;
 }
 
-static SDL_hapticlist_item *
-HapticByDevId (int device_id)
+static SDL_hapticlist_item *HapticByDevId(int device_id)
 {
     SDL_hapticlist_item *item;
-    for (item = SDL_hapticlist; item != NULL; item = item->next) {
+    for (item = SDL_hapticlist; item; item = item->next) {
         if (device_id == item->device_id) {
             /*SDL_Log("=+=+=+=+=+= HapticByDevId id [%d]", device_id);*/
             return item;
@@ -94,26 +89,23 @@ HapticByDevId (int device_id)
     return NULL;
 }
 
-const char *
-SDL_SYS_HapticName(int index)
+const char *SDL_SYS_HapticName(int index)
 {
     SDL_hapticlist_item *item = HapticByOrder(index);
-    if (item == NULL ) {
+    if (!item) {
         SDL_SetError("No such device");
         return NULL;
     }
     return item->name;
 }
 
-
-static SDL_hapticlist_item *
-OpenHaptic(SDL_Haptic *haptic, SDL_hapticlist_item *item)
+static SDL_hapticlist_item *OpenHaptic(SDL_Haptic *haptic, SDL_hapticlist_item *item)
 {
-    if (item == NULL ) {
+    if (!item) {
         SDL_SetError("No such device");
         return NULL;
     }
-    if (item->haptic != NULL) {
+    if (item->haptic) {
         SDL_SetError("Haptic already opened");
         return NULL;
     }
@@ -124,75 +116,59 @@ OpenHaptic(SDL_Haptic *haptic, SDL_hapticlist_item *item)
     haptic->supported = SDL_HAPTIC_LEFTRIGHT;
     haptic->neffects = 1;
     haptic->nplaying = haptic->neffects;
-    haptic->effects = (struct haptic_effect *)SDL_malloc (sizeof (struct haptic_effect) * haptic->neffects);
-    if (haptic->effects == NULL) {
+    haptic->effects = (struct haptic_effect *)SDL_malloc(sizeof(struct haptic_effect) * haptic->neffects);
+    if (!haptic->effects) {
         SDL_OutOfMemory();
         return NULL;
     }
-    SDL_memset(haptic->effects, 0, sizeof (struct haptic_effect) * haptic->neffects);
+    SDL_memset(haptic->effects, 0, sizeof(struct haptic_effect) * haptic->neffects);
     return item;
 }
 
-static SDL_hapticlist_item *
-OpenHapticByOrder(SDL_Haptic *haptic, int index)
+static SDL_hapticlist_item *OpenHapticByOrder(SDL_Haptic *haptic, int index)
 {
-    return OpenHaptic (haptic, HapticByOrder(index));
+    return OpenHaptic(haptic, HapticByOrder(index));
 }
 
-static SDL_hapticlist_item *
-OpenHapticByDevId(SDL_Haptic *haptic, int device_id)
+static SDL_hapticlist_item *OpenHapticByDevId(SDL_Haptic *haptic, int device_id)
 {
-    return OpenHaptic (haptic, HapticByDevId(device_id));
+    return OpenHaptic(haptic, HapticByDevId(device_id));
 }
 
-int
-SDL_SYS_HapticOpen(SDL_Haptic *haptic)
+int SDL_SYS_HapticOpen(SDL_Haptic *haptic)
 {
-    return (OpenHapticByOrder(haptic, haptic->index) == NULL ? -1 : 0);
+    return OpenHapticByOrder(haptic, haptic->index) == NULL ? -1 : 0;
 }
 
-
-int
-SDL_SYS_HapticMouse(void)
+int SDL_SYS_HapticMouse(void)
 {
     return -1;
 }
 
-
-int
-SDL_SYS_JoystickIsHaptic(SDL_Joystick *joystick)
+int SDL_SYS_JoystickIsHaptic(SDL_Joystick *joystick)
 {
     SDL_hapticlist_item *item;
     item = HapticByDevId(((joystick_hwdata *)joystick->hwdata)->device_id);
-    return (item != NULL) ? 1 : 0;
+    return (item) ? 1 : 0;
 }
 
-
-int
-SDL_SYS_HapticOpenFromJoystick(SDL_Haptic *haptic, SDL_Joystick *joystick)
+int SDL_SYS_HapticOpenFromJoystick(SDL_Haptic *haptic, SDL_Joystick *joystick)
 {
-    return (OpenHapticByDevId(haptic, ((joystick_hwdata *)joystick->hwdata)->device_id) == NULL ? -1 : 0);
+    return OpenHapticByDevId(haptic, ((joystick_hwdata *)joystick->hwdata)->device_id) == NULL ? -1 : 0;
 }
 
-
-int
-SDL_SYS_JoystickSameHaptic(SDL_Haptic * haptic, SDL_Joystick * joystick)
+int SDL_SYS_JoystickSameHaptic(SDL_Haptic *haptic, SDL_Joystick *joystick)
 {
-    return (((SDL_hapticlist_item *)haptic->hwdata)->device_id == ((joystick_hwdata *)joystick->hwdata)->device_id ? 1 : 0);
+    return ((SDL_hapticlist_item *)haptic->hwdata)->device_id == ((joystick_hwdata *)joystick->hwdata)->device_id ? 1 : 0;
 }
 
-
-void
-SDL_SYS_HapticClose(SDL_Haptic * haptic)
+void SDL_SYS_HapticClose(SDL_Haptic *haptic)
 {
     ((SDL_hapticlist_item *)haptic->hwdata)->haptic = NULL;
     haptic->hwdata = NULL;
-    return;
 }
 
-
-void
-SDL_SYS_HapticQuit(void)
+void SDL_SYS_HapticQuit(void)
 {
 /* We don't have any way to scan for joysticks (and their vibrators) at init, so don't wipe the list
  * of joysticks here in case this is a reinit.
@@ -212,111 +188,87 @@ SDL_SYS_HapticQuit(void)
 #endif
 }
 
-
-int
-SDL_SYS_HapticNewEffect(SDL_Haptic * haptic,
-                        struct haptic_effect *effect, SDL_HapticEffect * base)
+int SDL_SYS_HapticNewEffect(SDL_Haptic *haptic,
+                            struct haptic_effect *effect, SDL_HapticEffect *base)
 {
     return 0;
 }
 
-
-int
-SDL_SYS_HapticUpdateEffect(SDL_Haptic * haptic,
-                           struct haptic_effect *effect,
-                           SDL_HapticEffect * data)
+int SDL_SYS_HapticUpdateEffect(SDL_Haptic *haptic,
+                               struct haptic_effect *effect,
+                               SDL_HapticEffect *data)
 {
     return 0;
 }
 
-
-int
-SDL_SYS_HapticRunEffect(SDL_Haptic * haptic, struct haptic_effect *effect,
-                        Uint32 iterations)
+int SDL_SYS_HapticRunEffect(SDL_Haptic *haptic, struct haptic_effect *effect,
+                            Uint32 iterations)
 {
     float large = effect->effect.leftright.large_magnitude / 32767.0f;
     float small = effect->effect.leftright.small_magnitude / 32767.0f;
 
     float total = (large * 0.6f) + (small * 0.4f);
 
-    Android_JNI_HapticRun (((SDL_hapticlist_item *)haptic->hwdata)->device_id, total, effect->effect.leftright.length);
+    Android_JNI_HapticRun(((SDL_hapticlist_item *)haptic->hwdata)->device_id, total, effect->effect.leftright.length);
     return 0;
 }
 
-
-int
-SDL_SYS_HapticStopEffect(SDL_Haptic * haptic, struct haptic_effect *effect)
+int SDL_SYS_HapticStopEffect(SDL_Haptic *haptic, struct haptic_effect *effect)
 {
-    Android_JNI_HapticStop (((SDL_hapticlist_item *)haptic->hwdata)->device_id);
+    Android_JNI_HapticStop(((SDL_hapticlist_item *)haptic->hwdata)->device_id);
     return 0;
 }
 
-
-void
-SDL_SYS_HapticDestroyEffect(SDL_Haptic * haptic, struct haptic_effect *effect)
+void SDL_SYS_HapticDestroyEffect(SDL_Haptic *haptic, struct haptic_effect *effect)
 {
-    return;
 }
 
-
-int
-SDL_SYS_HapticGetEffectStatus(SDL_Haptic * haptic,
-                              struct haptic_effect *effect)
+int SDL_SYS_HapticGetEffectStatus(SDL_Haptic *haptic, struct haptic_effect *effect)
 {
     return 0;
 }
 
-
-int
-SDL_SYS_HapticSetGain(SDL_Haptic * haptic, int gain)
+int SDL_SYS_HapticSetGain(SDL_Haptic *haptic, int gain)
 {
     return 0;
 }
 
-
-int
-SDL_SYS_HapticSetAutocenter(SDL_Haptic * haptic, int autocenter)
+int SDL_SYS_HapticSetAutocenter(SDL_Haptic *haptic, int autocenter)
 {
     return 0;
 }
 
-int
-SDL_SYS_HapticPause(SDL_Haptic * haptic)
+int SDL_SYS_HapticPause(SDL_Haptic *haptic)
 {
     return 0;
 }
 
-int
-SDL_SYS_HapticUnpause(SDL_Haptic * haptic)
+int SDL_SYS_HapticUnpause(SDL_Haptic *haptic)
 {
     return 0;
 }
 
-int
-SDL_SYS_HapticStopAll(SDL_Haptic * haptic)
+int SDL_SYS_HapticStopAll(SDL_Haptic *haptic)
 {
     return 0;
 }
 
-
-
-int
-Android_AddHaptic(int device_id, const char *name)
+int Android_AddHaptic(int device_id, const char *name)
 {
     SDL_hapticlist_item *item;
-    item = (SDL_hapticlist_item *) SDL_calloc(1, sizeof (SDL_hapticlist_item));
-    if (item == NULL) {
+    item = (SDL_hapticlist_item *)SDL_calloc(1, sizeof(SDL_hapticlist_item));
+    if (!item) {
         return -1;
     }
 
     item->device_id = device_id;
-    item->name = SDL_strdup (name);
-    if (item->name == NULL) {
-        SDL_free (item);
+    item->name = SDL_strdup(name);
+    if (!item->name) {
+        SDL_free(item);
         return -1;
     }
 
-    if (SDL_hapticlist_tail == NULL) {
+    if (!SDL_hapticlist_tail) {
         SDL_hapticlist = SDL_hapticlist_tail = item;
     } else {
         SDL_hapticlist_tail->next = item;
@@ -327,18 +279,17 @@ Android_AddHaptic(int device_id, const char *name)
     return numhaptics;
 }
 
-int 
-Android_RemoveHaptic(int device_id)
+int Android_RemoveHaptic(int device_id)
 {
     SDL_hapticlist_item *item;
     SDL_hapticlist_item *prev = NULL;
 
-    for (item = SDL_hapticlist; item != NULL; item = item->next) {
+    for (item = SDL_hapticlist; item; item = item->next) {
         /* found it, remove it. */
         if (device_id == item->device_id) {
             const int retval = item->haptic ? item->haptic->index : -1;
 
-            if (prev != NULL) {
+            if (prev) {
                 prev->next = item->next;
             } else {
                 SDL_assert(SDL_hapticlist == item);
@@ -361,7 +312,6 @@ Android_RemoveHaptic(int device_id)
     return -1;
 }
 
-
 #endif /* SDL_HAPTIC_ANDROID */
 
 /* vi: set ts=4 sw=4 expandtab: */
