@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2018 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2024 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -18,10 +18,15 @@
      misrepresented as being the original software.
   3. This notice may not be removed or altered from any source distribution.
 */
+
+#ifndef SDL_drawpoint_h_
+#define SDL_drawpoint_h_
+
 #include "../../SDL_internal.h"
 
+extern int SDL_DrawPoint(SDL_Surface *dst, int x, int y, Uint32 color);
+extern int SDL_DrawPoints(SDL_Surface *dst, const SDL_Point *points, int count, Uint32 color);
 
-extern int SDL_DrawPoint(SDL_Surface * dst, int x, int y, Uint32 color);
-extern int SDL_DrawPoints(SDL_Surface * dst, const SDL_Point * points, int count, Uint32 color);
+#endif /* SDL_drawpoint_h_ */
 
 /* vi: set ts=4 sw=4 expandtab: */
