@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2024 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -37,15 +37,14 @@ struct SDL_cond
 };
 
 /* Create a condition variable */
-extern "C"
-SDL_cond *
+extern "C" SDL_cond *
 SDL_CreateCond(void)
 {
     /* Allocate and initialize the condition variable */
     try {
-        SDL_cond * cond = new SDL_cond;
+        SDL_cond *cond = new SDL_cond;
         return cond;
-    } catch (std::system_error & ex) {
+    } catch (std::system_error &ex) {
         SDL_SetError("unable to create a C++ condition variable: code=%d; %s", ex.code(), ex.what());
         return NULL;
     } catch (std::bad_alloc &) {
@@ -55,9 +54,8 @@ SDL_CreateCond(void)
 }
 
 /* Destroy a condition variable */
-extern "C"
-void
-SDL_DestroyCond(SDL_cond * cond)
+extern "C" void
+SDL_DestroyCond(SDL_cond *cond)
 {
     if (cond) {
         delete cond;
@@ -65,9 +63,8 @@ SDL_DestroyCond(SDL_cond * cond)
 }
 
 /* Restart one of the threads that are waiting on the condition variable */
-extern "C"
-int
-SDL_CondSignal(SDL_cond * cond)
+extern "C" int
+SDL_CondSignal(SDL_cond *cond)
 {
     if (!cond) {
         return SDL_InvalidParamError("cond");
@@ -78,9 +75,8 @@ SDL_CondSignal(SDL_cond * cond)
 }
 
 /* Restart all threads that are waiting on the condition variable */
-extern "C"
-int
-SDL_CondBroadcast(SDL_cond * cond)
+extern "C" int
+SDL_CondBroadcast(SDL_cond *cond)
 {
     if (!cond) {
         return SDL_InvalidParamError("cond");
@@ -111,15 +107,14 @@ Thread B:
     SDL_CondSignal(cond);
     SDL_UnlockMutex(lock);
  */
-extern "C"
-int
-SDL_CondWaitTimeout(SDL_cond * cond, SDL_mutex * mutex, Uint32 ms)
+extern "C" int
+SDL_CondWaitTimeout(SDL_cond *cond, SDL_mutex *mutex, Uint32 ms)
 {
-    if (!cond) {
+    if (cond == NULL) {
         return SDL_InvalidParamError("cond");
     }
 
-    if (!mutex) {
+    if (mutex == NULL) {
         return SDL_InvalidParamError("mutex");
     }
 
@@ -127,15 +122,13 @@ SDL_CondWaitTimeout(SDL_cond * cond, SDL_mutex * mutex, Uint32 ms)
         std::unique_lock<std::recursive_mutex> cpp_lock(mutex->cpp_mutex, std::adopt_lock_t());
         if (ms == SDL_MUTEX_MAXWAIT) {
             cond->cpp_cond.wait(
-                cpp_lock
-                );
+                cpp_lock);
             cpp_lock.release();
             return 0;
         } else {
             auto wait_result = cond->cpp_cond.wait_for(
                 cpp_lock,
-                std::chrono::duration<Uint32, std::milli>(ms)
-                );
+                std::chrono::duration<Uint32, std::milli>(ms));
             cpp_lock.release();
             if (wait_result == std::cv_status::timeout) {
                 return SDL_MUTEX_TIMEDOUT;
@@ -143,15 +136,14 @@ SDL_CondWaitTimeout(SDL_cond * cond, SDL_mutex * mutex, Uint32 ms)
                 return 0;
             }
         }
-    } catch (std::system_error & ex) {
+    } catch (std::system_error &ex) {
         return SDL_SetError("unable to wait on a C++ condition variable: code=%d; %s", ex.code(), ex.what());
     }
 }
 
 /* Wait on the condition variable forever */
-extern "C"
-int
-SDL_CondWait(SDL_cond * cond, SDL_mutex * mutex)
+extern "C" int
+SDL_CondWait(SDL_cond *cond, SDL_mutex *mutex)
 {
     return SDL_CondWaitTimeout(cond, mutex, SDL_MUTEX_MAXWAIT);
 }
