@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2024 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -24,48 +24,46 @@
 #include "SDL_blit.h"
 #include "SDL_blit_copy.h"
 
-
 #ifdef __SSE__
 /* This assumes 16-byte aligned src and dst */
-static SDL_INLINE void
-SDL_memcpySSE(Uint8 * dst, const Uint8 * src, int len)
+static SDL_INLINE void SDL_memcpySSE(Uint8 *dst, const Uint8 *src, int len)
 {
     int i;
 
     __m128 values[4];
     for (i = len / 64; i--;) {
         _mm_prefetch((const char *)src, _MM_HINT_NTA);
-        values[0] = *(__m128 *) (src + 0);
-        values[1] = *(__m128 *) (src + 16);
-        values[2] = *(__m128 *) (src + 32);
-        values[3] = *(__m128 *) (src + 48);
-        _mm_stream_ps((float *) (dst + 0), values[0]);
-        _mm_stream_ps((float *) (dst + 16), values[1]);
-        _mm_stream_ps((float *) (dst + 32), values[2]);
-        _mm_stream_ps((float *) (dst + 48), values[3]);
+        values[0] = *(__m128 *)(src + 0);
+        values[1] = *(__m128 *)(src + 16);
+        values[2] = *(__m128 *)(src + 32);
+        values[3] = *(__m128 *)(src + 48);
+        _mm_stream_ps((float *)(dst + 0), values[0]);
+        _mm_stream_ps((float *)(dst + 16), values[1]);
+        _mm_stream_ps((float *)(dst + 32), values[2]);
+        _mm_stream_ps((float *)(dst + 48), values[3]);
         src += 64;
         dst += 64;
     }
 
-    if (len & 63)
+    if (len & 63) {
         SDL_memcpy(dst, src, len & 63);
+    }
 }
 #endif /* __SSE__ */
 
 #ifdef __MMX__
 #ifdef _MSC_VER
-#pragma warning(disable:4799)
+#pragma warning(disable : 4799)
 #endif
-static SDL_INLINE void
-SDL_memcpyMMX(Uint8 * dst, const Uint8 * src, int len)
+static SDL_INLINE void SDL_memcpyMMX(Uint8 *dst, const Uint8 *src, int len)
 {
-    const int remain = (len & 63);
+    int remain = len & 63;
     int i;
 
-    __m64* d64 = (__m64*)dst;
-    __m64* s64 = (__m64*)src;
+    __m64 *d64 = (__m64 *)dst;
+    __m64 *s64 = (__m64 *)src;
 
-    for(i= len / 64; i--;) {
+    for (i = len / 64; i--;) {
         d64[0] = s64[0];
         d64[1] = s64[1];
         d64[2] = s64[2];
@@ -79,16 +77,18 @@ SDL_memcpyMMX(Uint8 * dst, const Uint8 * src, int len)
         s64 += 8;
     }
 
-    if (remain)
-    {
+    if (remain) {
         const int skip = len - remain;
-        SDL_memcpy(dst + skip, src + skip, remain);
+        dst += skip;
+        src += skip;
+        while (remain--) {
+            *dst++ = *src++;
+        }
     }
 }
 #endif /* __MMX__ */
 
-void
-SDL_BlitCopy(SDL_BlitInfo * info)
+void SDL_BlitCopy(SDL_BlitInfo *info)
 {
     SDL_bool overlap;
     Uint8 *src, *dst;
@@ -104,33 +104,33 @@ SDL_BlitCopy(SDL_BlitInfo * info)
 
     /* Properly handle overlapping blits */
     if (src < dst) {
-        overlap = (dst < (src + h*srcskip));
+        overlap = (dst < (src + h * srcskip));
     } else {
-        overlap = (src < (dst + h*dstskip));
+        overlap = (src < (dst + h * dstskip));
     }
     if (overlap) {
-        if ( dst < src ) {
-                while ( h-- ) {
-                        SDL_memmove(dst, src, w);
-                        src += srcskip;
-                        dst += dstskip;
-                }
+        if (dst < src) {
+            while (h--) {
+                SDL_memmove(dst, src, w);
+                src += srcskip;
+                dst += dstskip;
+            }
         } else {
-                src += ((h-1) * srcskip);
-                dst += ((h-1) * dstskip);
-                while ( h-- ) {
-                        SDL_memmove(dst, src, w);
-                        src -= srcskip;
-                        dst -= dstskip;
-                }
+            src += ((h - 1) * srcskip);
+            dst += ((h - 1) * dstskip);
+            while (h--) {
+                SDL_memmove(dst, src, w);
+                src -= srcskip;
+                dst -= dstskip;
+            }
         }
         return;
     }
 
 #ifdef __SSE__
     if (SDL_HasSSE() &&
-        !((uintptr_t) src & 15) && !(srcskip & 15) &&
-        !((uintptr_t) dst & 15) && !(dstskip & 15)) {
+        !((uintptr_t)src & 15) && !(srcskip & 15) &&
+        !((uintptr_t)dst & 15) && !(dstskip & 15)) {
         while (h--) {
             SDL_memcpySSE(dst, src, w);
             src += srcskip;
