@@ -4,8 +4,12 @@
  */
 
 /* Supress C4996 VS compiler warnings for unlink() */
+#if defined(_MSC_VER) && !defined(_CRT_SECURE_NO_DEPRECATE)
 #define _CRT_SECURE_NO_DEPRECATE
+#endif
+#if defined(_MSC_VER) && !defined(_CRT_NONSTDC_NO_DEPRECATE)
 #define _CRT_NONSTDC_NO_DEPRECATE
+#endif
 
 #include <stdio.h>
 #ifndef _MSC_VER
@@ -29,14 +33,13 @@ static SDL_Surface *testSurface = NULL;
 
 /* Helper functions for the test cases */
 
-#define TEST_SURFACE_WIDTH testSurface->w
+#define TEST_SURFACE_WIDTH  testSurface->w
 #define TEST_SURFACE_HEIGHT testSurface->h
 
 /* Fixture */
 
 /* Create a 32-bit writable surface for blitting tests */
-void
-_surfaceSetUp(void *arg)
+void _surfaceSetUp(void *arg)
 {
     int result;
     SDL_BlendMode blendMode = SDL_BLENDMODE_NONE;
@@ -58,17 +61,16 @@ _surfaceSetUp(void *arg)
     testSurface = SDL_CreateRGBSurface(SDL_SWSURFACE, referenceSurface->w, referenceSurface->h, 32, rmask, gmask, bmask, amask);
     SDLTest_AssertCheck(testSurface != NULL, "Check that testSurface is not NULL");
     if (testSurface != NULL) {
-      /* Disable blend mode for target surface */
-      result = SDL_SetSurfaceBlendMode(testSurface, blendMode);
-      SDLTest_AssertCheck(result == 0, "Validate result from SDL_SetSurfaceBlendMode, expected: 0, got: %i", result);
-      result = SDL_GetSurfaceBlendMode(testSurface, &currentBlendMode);
-      SDLTest_AssertCheck(result == 0, "Validate result from SDL_GetSurfaceBlendMode, expected: 0, got: %i", result);
-      SDLTest_AssertCheck(currentBlendMode == blendMode, "Validate blendMode, expected: %i, got: %i", blendMode, currentBlendMode);
+        /* Disable blend mode for target surface */
+        result = SDL_SetSurfaceBlendMode(testSurface, blendMode);
+        SDLTest_AssertCheck(result == 0, "Validate result from SDL_SetSurfaceBlendMode, expected: 0, got: %i", result);
+        result = SDL_GetSurfaceBlendMode(testSurface, &currentBlendMode);
+        SDLTest_AssertCheck(result == 0, "Validate result from SDL_GetSurfaceBlendMode, expected: 0, got: %i", result);
+        SDLTest_AssertCheck(currentBlendMode == blendMode, "Validate blendMode, expected: %i, got: %i", blendMode, currentBlendMode);
     }
 }
 
-void
-_surfaceTearDown(void *arg)
+void _surfaceTearDown(void *arg)
 {
     SDL_FreeSurface(referenceSurface);
     referenceSurface = NULL;
@@ -85,9 +87,9 @@ void _clearTestSurface()
     Uint32 color;
 
     /* Clear surface. */
-    color = SDL_MapRGBA( testSurface->format, 0, 0, 0, 0);
+    color = SDL_MapRGBA(testSurface->format, 0, 0, 0, 0);
     SDLTest_AssertPass("Call to SDL_MapRGBA()");
-    ret = SDL_FillRect( testSurface, NULL, color);
+    ret = SDL_FillRect(testSurface, NULL, color);
     SDLTest_AssertPass("Call to SDL_FillRect()");
     SDLTest_AssertCheck(ret == 0, "Verify result from SDL_FillRect, expected: 0, got: %i", ret);
 }
@@ -110,30 +112,34 @@ void _testBlitBlendMode(int mode)
 
     /* Check test surface */
     SDLTest_AssertCheck(testSurface != NULL, "Verify testSurface is not NULL");
-    if (testSurface == NULL) return;
+    if (testSurface == NULL) {
+        return;
+    }
 
     /* Create sample surface */
     face = SDLTest_ImageFace();
     SDLTest_AssertCheck(face != NULL, "Verify face surface is not NULL");
-    if (face == NULL) return;
+    if (face == NULL) {
+        return;
+    }
 
-        /* Reset alpha modulation */
+    /* Reset alpha modulation */
     ret = SDL_SetSurfaceAlphaMod(face, 255);
     SDLTest_AssertPass("Call to SDL_SetSurfaceAlphaMod()");
     SDLTest_AssertCheck(ret == 0, "Verify result from SDL_SetSurfaceAlphaMod(), expected: 0, got: %i", ret);
 
-        /* Reset color modulation */
+    /* Reset color modulation */
     ret = SDL_SetSurfaceColorMod(face, 255, 255, 255);
     SDLTest_AssertPass("Call to SDL_SetSurfaceColorMod()");
     SDLTest_AssertCheck(ret == 0, "Verify result from SDL_SetSurfaceColorMod(), expected: 0, got: %i", ret);
 
-        /* Reset color key */
+    /* Reset color key */
     ret = SDL_SetColorKey(face, SDL_FALSE, 0);
     SDLTest_AssertPass("Call to SDL_SetColorKey()");
     SDLTest_AssertCheck(ret == 0, "Verify result from SDL_SetColorKey(), expected: 0, got: %i", ret);
 
     /* Clear the test surface */
-        _clearTestSurface();
+    _clearTestSurface();
 
     /* Target rect size */
     rect.w = face->w;
@@ -145,7 +151,7 @@ void _testBlitBlendMode(int mode)
 
     /* Optionally set blend mode. */
     if (mode >= 0) {
-        ret = SDL_SetSurfaceBlendMode( face, (SDL_BlendMode)mode );
+        ret = SDL_SetSurfaceBlendMode(face, (SDL_BlendMode)mode);
         SDLTest_AssertPass("Call to SDL_SetSurfaceBlendMode()");
         SDLTest_AssertCheck(ret == 0, "Verify result from SDL_SetSurfaceBlendMode(..., %i), expected: 0, got: %i", mode, ret);
     }
@@ -155,44 +161,50 @@ void _testBlitBlendMode(int mode)
     checkFailCount2 = 0;
     checkFailCount3 = 0;
     checkFailCount4 = 0;
-    for (j=0; j <= nj; j+=4) {
-      for (i=0; i <= ni; i+=4) {
-        if (mode == -2) {
-            /* Set color mod. */
-            ret = SDL_SetSurfaceColorMod( face, (255/nj)*j, (255/ni)*i, (255/nj)*j );
-            if (ret != 0) checkFailCount2++;
-        }
-        else if (mode == -3) {
-            /* Set alpha mod. */
-            ret = SDL_SetSurfaceAlphaMod( face, (255/ni)*i );
-            if (ret != 0) checkFailCount3++;
-        }
-        else if (mode == -4) {
-            /* Crazy blending mode magic. */
-            nmode = (i/4*j/4) % 4;
-            if (nmode==0) {
-                bmode = SDL_BLENDMODE_NONE;
-            } else if (nmode==1) {
-                bmode = SDL_BLENDMODE_BLEND;
-            } else if (nmode==2) {
-                bmode = SDL_BLENDMODE_ADD;
-            } else if (nmode==3) {
-                bmode = SDL_BLENDMODE_MOD;
-            } else {
-                /* Should be impossible, but some static checkers are too imprecise and will complain */
-                SDLTest_LogError("Invalid: nmode=%d", nmode);
-                return;
+    for (j = 0; j <= nj; j += 4) {
+        for (i = 0; i <= ni; i += 4) {
+            if (mode == -2) {
+                /* Set color mod. */
+                ret = SDL_SetSurfaceColorMod(face, (255 / nj) * j, (255 / ni) * i, (255 / nj) * j);
+                if (ret != 0) {
+                    checkFailCount2++;
+                }
+            } else if (mode == -3) {
+                /* Set alpha mod. */
+                ret = SDL_SetSurfaceAlphaMod(face, (255 / ni) * i);
+                if (ret != 0) {
+                    checkFailCount3++;
+                }
+            } else if (mode == -4) {
+                /* Crazy blending mode magic. */
+                nmode = (i / 4 * j / 4) % 4;
+                if (nmode == 0) {
+                    bmode = SDL_BLENDMODE_NONE;
+                } else if (nmode == 1) {
+                    bmode = SDL_BLENDMODE_BLEND;
+                } else if (nmode == 2) {
+                    bmode = SDL_BLENDMODE_ADD;
+                } else if (nmode == 3) {
+                    bmode = SDL_BLENDMODE_MOD;
+                } else {
+                    /* Should be impossible, but some static checkers are too imprecise and will complain */
+                    SDLTest_LogError("Invalid: nmode=%d", nmode);
+                    return;
+                }
+                ret = SDL_SetSurfaceBlendMode(face, bmode);
+                if (ret != 0) {
+                    checkFailCount4++;
+                }
             }
-            ret = SDL_SetSurfaceBlendMode( face, bmode );
-            if (ret != 0) checkFailCount4++;
-        }
 
-         /* Blitting. */
-         rect.x = i;
-         rect.y = j;
-         ret = SDL_BlitSurface( face, NULL, testSurface, &rect );
-         if (ret != 0) checkFailCount1++;
-      }
+            /* Blitting. */
+            rect.x = i;
+            rect.y = j;
+            ret = SDL_BlitSurface(face, NULL, testSurface, &rect);
+            if (ret != 0) {
+                checkFailCount1++;
+            }
+        }
     }
     SDLTest_AssertCheck(checkFailCount1 == 0, "Validate results from calls to SDL_BlitSurface, expected: 0, got: %i", checkFailCount1);
     SDLTest_AssertCheck(checkFailCount2 == 0, "Validate results from calls to SDL_SetSurfaceColorMod, expected: 0, got: %i", checkFailCount2);
@@ -205,8 +217,7 @@ void _testBlitBlendMode(int mode)
 }
 
 /* Helper to check that a file exists */
-void
-_AssertFileExist(const char *filename)
+void _AssertFileExist(const char *filename)
 {
     struct stat st;
     int ret = stat(filename, &st);
@@ -214,14 +225,12 @@ _AssertFileExist(const char *filename)
     SDLTest_AssertCheck(ret == 0, "Verify file '%s' exists", filename);
 }
 
-
 /* Test case functions */
 
 /**
  * @brief Tests sprite saving and loading
  */
-int
-surface_testSaveLoadBitmap(void *arg)
+int surface_testSaveLoadBitmap(void *arg)
 {
     int ret;
     const char *sampleFilename = "testSaveLoadBitmap.bmp";
@@ -231,7 +240,9 @@ surface_testSaveLoadBitmap(void *arg)
     /* Create sample surface */
     face = SDLTest_ImageFace();
     SDLTest_AssertCheck(face != NULL, "Verify face surface is not NULL");
-    if (face == NULL) return TEST_ABORTED;
+    if (face == NULL) {
+        return TEST_ABORTED;
+    }
 
     /* Delete test file; ignore errors */
     unlink(sampleFilename);
@@ -266,8 +277,7 @@ surface_testSaveLoadBitmap(void *arg)
 /* !
  *  Tests surface conversion.
  */
-int
-surface_testSurfaceConversion(void *arg)
+int surface_testSurfaceConversion(void *arg)
 {
     SDL_Surface *rface = NULL, *face = NULL;
     int ret = 0;
@@ -275,14 +285,15 @@ surface_testSurfaceConversion(void *arg)
     /* Create sample surface */
     face = SDLTest_ImageFace();
     SDLTest_AssertCheck(face != NULL, "Verify face surface is not NULL");
-    if (face == NULL)
+    if (face == NULL) {
         return TEST_ABORTED;
+    }
 
     /* Set transparent pixel as the pixel at (0,0) */
     if (face->format->palette) {
-       ret = SDL_SetColorKey(face, SDL_RLEACCEL, *(Uint8 *) face->pixels);
-       SDLTest_AssertPass("Call to SDL_SetColorKey()");
-       SDLTest_AssertCheck(ret == 0, "Verify result from SDL_SetColorKey, expected: 0, got: %i", ret);
+        ret = SDL_SetColorKey(face, SDL_RLEACCEL, *(Uint8 *)face->pixels);
+        SDLTest_AssertPass("Call to SDL_SetColorKey()");
+        SDLTest_AssertCheck(ret == 0, "Verify result from SDL_SetColorKey, expected: 0, got: %i", ret);
     }
 
     /* Convert to 32 bit to compare. */
@@ -291,7 +302,7 @@ surface_testSurfaceConversion(void *arg)
     SDLTest_AssertCheck(rface != NULL, "Verify result from SDL_ConvertSurface is not NULL");
 
     /* Compare surface. */
-    ret = SDLTest_CompareSurfaces( rface, face, 0 );
+    ret = SDLTest_CompareSurfaces(rface, face, 0);
     SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
 
     /* Clean up. */
@@ -303,12 +314,10 @@ surface_testSurfaceConversion(void *arg)
     return TEST_COMPLETED;
 }
 
-
 /* !
  *  Tests surface conversion across all pixel formats.
  */
-int
-surface_testCompleteSurfaceConversion(void *arg)
+int surface_testCompleteSurfaceConversion(void *arg)
 {
     Uint32 pixel_formats[] = {
         SDL_PIXELFORMAT_INDEX8,
@@ -346,18 +355,19 @@ surface_testCompleteSurfaceConversion(void *arg)
     /* Create sample surface */
     face = SDLTest_ImageFace();
     SDLTest_AssertCheck(face != NULL, "Verify face surface is not NULL");
-    if (face == NULL)
+    if (face == NULL) {
         return TEST_ABORTED;
+    }
 
     /* Set transparent pixel as the pixel at (0,0) */
     if (face->format->palette) {
-       ret = SDL_SetColorKey(face, SDL_RLEACCEL, *(Uint8 *) face->pixels);
-       SDLTest_AssertPass("Call to SDL_SetColorKey()");
-       SDLTest_AssertCheck(ret == 0, "Verify result from SDL_SetColorKey, expected: 0, got: %i", ret);
+        ret = SDL_SetColorKey(face, SDL_RLEACCEL, *(Uint8 *)face->pixels);
+        SDLTest_AssertPass("Call to SDL_SetColorKey()");
+        SDLTest_AssertCheck(ret == 0, "Verify result from SDL_SetColorKey, expected: 0, got: %i", ret);
     }
 
-    for ( i = 0; i < SDL_arraysize(pixel_formats); ++i ) {
-        for ( j = 0; j < SDL_arraysize(pixel_formats); ++j ) {
+    for (i = 0; i < SDL_arraysize(pixel_formats); ++i) {
+        for (j = 0; j < SDL_arraysize(pixel_formats); ++j) {
             fmt1 = SDL_AllocFormat(pixel_formats[i]);
             SDL_assert(fmt1 != NULL);
             cvt1 = SDL_ConvertSurface(face, fmt1, 0);
@@ -376,7 +386,7 @@ surface_testCompleteSurfaceConversion(void *arg)
                 SDL_assert(final != NULL);
 
                 /* Compare surface. */
-                ret = SDLTest_CompareSurfaces( face, final, 0 );
+                ret = SDLTest_CompareSurfaces(face, final, 0);
                 SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
                 SDL_FreeSurface(final);
             }
@@ -389,17 +399,15 @@ surface_testCompleteSurfaceConversion(void *arg)
     }
 
     /* Clean up. */
-    SDL_FreeSurface( face );
+    SDL_FreeSurface(face);
 
     return TEST_COMPLETED;
 }
 
-
 /**
  * @brief Tests sprite loading. A failure case.
  */
-int
-surface_testLoadFailure(void *arg)
+int surface_testLoadFailure(void *arg)
 {
     SDL_Surface *face = SDL_LoadBMP("nonexistant.bmp");
     SDLTest_AssertCheck(face == NULL, "SDL_CreateLoadBmp");
@@ -410,191 +418,181 @@ surface_testLoadFailure(void *arg)
 /**
  * @brief Tests some blitting routines.
  */
-int
-surface_testBlit(void *arg)
+int surface_testBlit(void *arg)
 {
-   int ret;
-   SDL_Surface *compareSurface;
+    int ret;
+    SDL_Surface *compareSurface;
 
-   /* Basic blitting */
-   _testBlitBlendMode(-1);
+    /* Basic blitting */
+    _testBlitBlendMode(-1);
 
-   /* Verify result by comparing surfaces */
-   compareSurface = SDLTest_ImageBlit();
-   ret = SDLTest_CompareSurfaces( testSurface, compareSurface, 0 );
-   SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
+    /* Verify result by comparing surfaces */
+    compareSurface = SDLTest_ImageBlit();
+    ret = SDLTest_CompareSurfaces(testSurface, compareSurface, 0);
+    SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
 
-   /* Clean up. */
-   SDL_FreeSurface(compareSurface);
+    /* Clean up. */
+    SDL_FreeSurface(compareSurface);
 
-   return TEST_COMPLETED;
+    return TEST_COMPLETED;
 }
 
 /**
  * @brief Tests some blitting routines with color mod
  */
-int
-surface_testBlitColorMod(void *arg)
+int surface_testBlitColorMod(void *arg)
 {
-   int ret;
-   SDL_Surface *compareSurface;
+    int ret;
+    SDL_Surface *compareSurface;
 
-   /* Basic blitting with color mod */
-   _testBlitBlendMode(-2);
+    /* Basic blitting with color mod */
+    _testBlitBlendMode(-2);
 
-   /* Verify result by comparing surfaces */
-   compareSurface = SDLTest_ImageBlitColor();
-   ret = SDLTest_CompareSurfaces( testSurface, compareSurface, 0 );
-   SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
+    /* Verify result by comparing surfaces */
+    compareSurface = SDLTest_ImageBlitColor();
+    ret = SDLTest_CompareSurfaces(testSurface, compareSurface, 0);
+    SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
 
-   /* Clean up. */
-   SDL_FreeSurface(compareSurface);
+    /* Clean up. */
+    SDL_FreeSurface(compareSurface);
 
-   return TEST_COMPLETED;
+    return TEST_COMPLETED;
 }
 
 /**
  * @brief Tests some blitting routines with alpha mod
  */
-int
-surface_testBlitAlphaMod(void *arg)
+int surface_testBlitAlphaMod(void *arg)
 {
-   int ret;
-   SDL_Surface *compareSurface;
+    int ret;
+    SDL_Surface *compareSurface;
 
-   /* Basic blitting with alpha mod */
-   _testBlitBlendMode(-3);
+    /* Basic blitting with alpha mod */
+    _testBlitBlendMode(-3);
 
-   /* Verify result by comparing surfaces */
-   compareSurface = SDLTest_ImageBlitAlpha();
-   ret = SDLTest_CompareSurfaces( testSurface, compareSurface, 0 );
-   SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
+    /* Verify result by comparing surfaces */
+    compareSurface = SDLTest_ImageBlitAlpha();
+    ret = SDLTest_CompareSurfaces(testSurface, compareSurface, 0);
+    SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
 
-   /* Clean up. */
-   SDL_FreeSurface(compareSurface);
+    /* Clean up. */
+    SDL_FreeSurface(compareSurface);
 
-   return TEST_COMPLETED;
-}
-
-
-/**
- * @brief Tests some more blitting routines.
- */
-int
-surface_testBlitBlendNone(void *arg)
-{
-   int ret;
-   SDL_Surface *compareSurface;
-
-   /* Basic blitting */
-   _testBlitBlendMode(SDL_BLENDMODE_NONE);
-
-   /* Verify result by comparing surfaces */
-   compareSurface = SDLTest_ImageBlitBlendNone();
-   ret = SDLTest_CompareSurfaces( testSurface, compareSurface, 0 );
-   SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
-
-   /* Clean up. */
-   SDL_FreeSurface(compareSurface);
-
-   return TEST_COMPLETED;
+    return TEST_COMPLETED;
 }
 
 /**
  * @brief Tests some more blitting routines.
  */
-int
-surface_testBlitBlendBlend(void *arg)
+int surface_testBlitBlendNone(void *arg)
 {
-   int ret;
-   SDL_Surface *compareSurface;
+    int ret;
+    SDL_Surface *compareSurface;
 
-   /* Blend blitting */
-   _testBlitBlendMode(SDL_BLENDMODE_BLEND);
+    /* Basic blitting */
+    _testBlitBlendMode(SDL_BLENDMODE_NONE);
 
-   /* Verify result by comparing surfaces */
-   compareSurface = SDLTest_ImageBlitBlend();
-   ret = SDLTest_CompareSurfaces( testSurface, compareSurface, 0 );
-   SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
+    /* Verify result by comparing surfaces */
+    compareSurface = SDLTest_ImageBlitBlendNone();
+    ret = SDLTest_CompareSurfaces(testSurface, compareSurface, 0);
+    SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
 
-   /* Clean up. */
-   SDL_FreeSurface(compareSurface);
+    /* Clean up. */
+    SDL_FreeSurface(compareSurface);
 
-   return TEST_COMPLETED;
+    return TEST_COMPLETED;
 }
 
 /**
  * @brief Tests some more blitting routines.
  */
-int
-surface_testBlitBlendAdd(void *arg)
+int surface_testBlitBlendBlend(void *arg)
 {
-   int ret;
-   SDL_Surface *compareSurface;
+    int ret;
+    SDL_Surface *compareSurface;
 
-   /* Add blitting */
-   _testBlitBlendMode(SDL_BLENDMODE_ADD);
+    /* Blend blitting */
+    _testBlitBlendMode(SDL_BLENDMODE_BLEND);
 
-   /* Verify result by comparing surfaces */
-   compareSurface = SDLTest_ImageBlitBlendAdd();
-   ret = SDLTest_CompareSurfaces( testSurface, compareSurface, 0 );
-   SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
+    /* Verify result by comparing surfaces */
+    compareSurface = SDLTest_ImageBlitBlend();
+    ret = SDLTest_CompareSurfaces(testSurface, compareSurface, 0);
+    SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
 
-   /* Clean up. */
-   SDL_FreeSurface(compareSurface);
+    /* Clean up. */
+    SDL_FreeSurface(compareSurface);
 
-   return TEST_COMPLETED;
+    return TEST_COMPLETED;
 }
 
 /**
  * @brief Tests some more blitting routines.
  */
-int
-surface_testBlitBlendMod(void *arg)
+int surface_testBlitBlendAdd(void *arg)
 {
-   int ret;
-   SDL_Surface *compareSurface;
+    int ret;
+    SDL_Surface *compareSurface;
 
-   /* Mod blitting */
-   _testBlitBlendMode(SDL_BLENDMODE_MOD);
+    /* Add blitting */
+    _testBlitBlendMode(SDL_BLENDMODE_ADD);
 
-   /* Verify result by comparing surfaces */
-   compareSurface = SDLTest_ImageBlitBlendMod();
-   ret = SDLTest_CompareSurfaces( testSurface, compareSurface, 0 );
-   SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
+    /* Verify result by comparing surfaces */
+    compareSurface = SDLTest_ImageBlitBlendAdd();
+    ret = SDLTest_CompareSurfaces(testSurface, compareSurface, 0);
+    SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
 
-   /* Clean up. */
-   SDL_FreeSurface(compareSurface);
+    /* Clean up. */
+    SDL_FreeSurface(compareSurface);
 
-   return TEST_COMPLETED;
+    return TEST_COMPLETED;
+}
+
+/**
+ * @brief Tests some more blitting routines.
+ */
+int surface_testBlitBlendMod(void *arg)
+{
+    int ret;
+    SDL_Surface *compareSurface;
+
+    /* Mod blitting */
+    _testBlitBlendMode(SDL_BLENDMODE_MOD);
+
+    /* Verify result by comparing surfaces */
+    compareSurface = SDLTest_ImageBlitBlendMod();
+    ret = SDLTest_CompareSurfaces(testSurface, compareSurface, 0);
+    SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
+
+    /* Clean up. */
+    SDL_FreeSurface(compareSurface);
+
+    return TEST_COMPLETED;
 }
 
 /**
  * @brief Tests some more blitting routines with loop
  */
-int
-surface_testBlitBlendLoop(void *arg) {
+int surface_testBlitBlendLoop(void *arg)
+{
 
-   int ret;
-   SDL_Surface *compareSurface;
+    int ret;
+    SDL_Surface *compareSurface;
 
-   /* All blitting modes */
-   _testBlitBlendMode(-4);
+    /* All blitting modes */
+    _testBlitBlendMode(-4);
 
-   /* Verify result by comparing surfaces */
-   compareSurface = SDLTest_ImageBlitBlendAll();
-   ret = SDLTest_CompareSurfaces( testSurface, compareSurface, 0 );
-   SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
+    /* Verify result by comparing surfaces */
+    compareSurface = SDLTest_ImageBlitBlendAll();
+    ret = SDLTest_CompareSurfaces(testSurface, compareSurface, 0);
+    SDLTest_AssertCheck(ret == 0, "Validate result from SDLTest_CompareSurfaces, expected: 0, got: %i", ret);
 
-   /* Clean up. */
-   SDL_FreeSurface(compareSurface);
-
-   return TEST_COMPLETED;
+    /* Clean up. */
+    SDL_FreeSurface(compareSurface);
 
+    return TEST_COMPLETED;
 }
 
-int
-surface_testOverflow(void *arg)
+int surface_testOverflow(void *arg)
 {
     char buf[1024];
     const char *expectedError;
@@ -670,6 +668,34 @@ surface_testOverflow(void *arg)
                         surface != NULL ? "(success)" : SDL_GetError());
     SDL_FreeSurface(surface);
 
+    /* SDL_PIXELFORMAT_INDEX2* needs 1 byte per 4 pixels. */
+    surface = SDL_CreateRGBSurfaceWithFormatFrom(buf, 12, 1, 2, 3, SDL_PIXELFORMAT_INDEX2LSB);
+    SDLTest_AssertCheck(surface != NULL, "12px * 2 bits per px fits in 3 bytes: %s",
+                        surface != NULL ? "(success)" : SDL_GetError());
+    SDL_FreeSurface(surface);
+    surface = SDL_CreateRGBSurfaceFrom(buf, 12, 1, 2, 3, 0, 0, 0, 0);
+    SDLTest_AssertCheck(surface != NULL, "12px * 2 bits per px fits in 3 bytes: %s",
+                        surface != NULL ? "(success)" : SDL_GetError());
+    SDL_FreeSurface(surface);
+
+    surface = SDL_CreateRGBSurfaceWithFormatFrom(buf, 13, 1, 2, 3, SDL_PIXELFORMAT_INDEX2LSB);
+    SDLTest_AssertCheck(surface == NULL, "Should detect pitch < width * bpp (%d)", surface ? surface->pitch : 0);
+    SDLTest_AssertCheck(SDL_strcmp(SDL_GetError(), expectedError) == 0,
+                        "Expected \"%s\", got \"%s\"", expectedError, SDL_GetError());
+    surface = SDL_CreateRGBSurfaceFrom(buf, 13, 1, 2, 3, 0, 0, 0, 0);
+    SDLTest_AssertCheck(surface == NULL, "Should detect pitch < width * bpp");
+    SDLTest_AssertCheck(SDL_strcmp(SDL_GetError(), expectedError) == 0,
+                        "Expected \"%s\", got \"%s\"", expectedError, SDL_GetError());
+
+    surface = SDL_CreateRGBSurfaceWithFormatFrom(buf, 13, 1, 2, 4, SDL_PIXELFORMAT_INDEX2LSB);
+    SDLTest_AssertCheck(surface != NULL, "13px * 2 bits per px fits in 4 bytes: %s",
+                        surface != NULL ? "(success)" : SDL_GetError());
+    SDL_FreeSurface(surface);
+    surface = SDL_CreateRGBSurfaceFrom(buf, 13, 1, 2, 4, 0, 0, 0, 0);
+    SDLTest_AssertCheck(surface != NULL, "13px * 2 bits per px fits in 4 bytes: %s",
+                        surface != NULL ? "(success)" : SDL_GetError());
+    SDL_FreeSurface(surface);
+
     /* SDL_PIXELFORMAT_INDEX1* needs 1 byte per 8 pixels. */
     surface = SDL_CreateRGBSurfaceWithFormatFrom(buf, 16, 1, 1, 2, SDL_PIXELFORMAT_INDEX1LSB);
     SDLTest_AssertCheck(surface != NULL, "16px * 1 bit per px fits in 2 bytes: %s",
@@ -738,26 +764,32 @@ surface_testOverflow(void *arg)
     SDLTest_AssertCheck(SDL_strcmp(SDL_GetError(), expectedError) == 0,
                         "Expected \"%s\", got \"%s\"", expectedError, SDL_GetError());
 
-    if (sizeof (size_t) == 4 && sizeof (int) >= 4) {
+    if (sizeof(size_t) == 4 && sizeof(int) >= 4) {
+        SDL_ClearError();
         expectedError = "Out of memory";
-        surface = SDL_CreateRGBSurfaceWithFormat(0, SDL_MAX_SINT32, 1, 8, SDL_PIXELFORMAT_INDEX8);
+        /* 0x5555'5555 * 3bpp = 0xffff'ffff which fits in size_t, but adding
+         * alignment padding makes it overflow */
+        surface = SDL_CreateRGBSurfaceWithFormat(0, 0x55555555, 1, 24, SDL_PIXELFORMAT_RGB24);
         SDLTest_AssertCheck(surface == NULL, "Should detect overflow in width + alignment");
         SDLTest_AssertCheck(SDL_strcmp(SDL_GetError(), expectedError) == 0,
                             "Expected \"%s\", got \"%s\"", expectedError, SDL_GetError());
-        surface = SDL_CreateRGBSurfaceWithFormat(0, SDL_MAX_SINT32 / 2, 1, 32, SDL_PIXELFORMAT_ARGB8888);
+        SDL_ClearError();
+        /* 0x4000'0000 * 4bpp = 0x1'0000'0000 which (just) overflows */
+        surface = SDL_CreateRGBSurfaceWithFormat(0, 0x40000000, 1, 32, SDL_PIXELFORMAT_ARGB8888);
         SDLTest_AssertCheck(surface == NULL, "Should detect overflow in width * bytes per pixel");
         SDLTest_AssertCheck(SDL_strcmp(SDL_GetError(), expectedError) == 0,
                             "Expected \"%s\", got \"%s\"", expectedError, SDL_GetError());
+        SDL_ClearError();
         surface = SDL_CreateRGBSurfaceWithFormat(0, (1 << 29) - 1, (1 << 29) - 1, 8, SDL_PIXELFORMAT_INDEX8);
         SDLTest_AssertCheck(surface == NULL, "Should detect overflow in width * height");
         SDLTest_AssertCheck(SDL_strcmp(SDL_GetError(), expectedError) == 0,
                             "Expected \"%s\", got \"%s\"", expectedError, SDL_GetError());
+        SDL_ClearError();
         surface = SDL_CreateRGBSurfaceWithFormat(0, (1 << 15) + 1, (1 << 15) + 1, 32, SDL_PIXELFORMAT_ARGB8888);
         SDLTest_AssertCheck(surface == NULL, "Should detect overflow in width * height * bytes per pixel");
         SDLTest_AssertCheck(SDL_strcmp(SDL_GetError(), expectedError) == 0,
                             "Expected \"%s\", got \"%s\"", expectedError, SDL_GetError());
-    }
-    else {
+    } else {
         SDLTest_Log("Can't easily overflow size_t on this platform");
     }
 
@@ -767,50 +799,63 @@ surface_testOverflow(void *arg)
 /* ================= Test References ================== */
 
 /* Surface test cases */
-static const SDLTest_TestCaseReference surfaceTest1 =
-        { (SDLTest_TestCaseFp)surface_testSaveLoadBitmap, "surface_testSaveLoadBitmap", "Tests sprite saving and loading.", TEST_ENABLED};
+static const SDLTest_TestCaseReference surfaceTest1 = {
+    (SDLTest_TestCaseFp)surface_testSaveLoadBitmap, "surface_testSaveLoadBitmap", "Tests sprite saving and loading.", TEST_ENABLED
+};
 
-static const SDLTest_TestCaseReference surfaceTest2 =
-        { (SDLTest_TestCaseFp)surface_testBlit, "surface_testBlit", "Tests basic blitting.", TEST_ENABLED};
+static const SDLTest_TestCaseReference surfaceTest2 = {
+    (SDLTest_TestCaseFp)surface_testBlit, "surface_testBlit", "Tests basic blitting.", TEST_ENABLED
+};
 
-static const SDLTest_TestCaseReference surfaceTest3 =
-        { (SDLTest_TestCaseFp)surface_testBlitBlendNone, "surface_testBlitBlendNone", "Tests blitting routines with none blending mode.", TEST_ENABLED};
+static const SDLTest_TestCaseReference surfaceTest3 = {
+    (SDLTest_TestCaseFp)surface_testBlitBlendNone, "surface_testBlitBlendNone", "Tests blitting routines with none blending mode.", TEST_ENABLED
+};
 
-static const SDLTest_TestCaseReference surfaceTest4 =
-        { (SDLTest_TestCaseFp)surface_testLoadFailure, "surface_testLoadFailure", "Tests sprite loading. A failure case.", TEST_ENABLED};
+static const SDLTest_TestCaseReference surfaceTest4 = {
+    (SDLTest_TestCaseFp)surface_testLoadFailure, "surface_testLoadFailure", "Tests sprite loading. A failure case.", TEST_ENABLED
+};
 
-static const SDLTest_TestCaseReference surfaceTest5 =
-        { (SDLTest_TestCaseFp)surface_testSurfaceConversion, "surface_testSurfaceConversion", "Tests surface conversion.", TEST_ENABLED};
+static const SDLTest_TestCaseReference surfaceTest5 = {
+    (SDLTest_TestCaseFp)surface_testSurfaceConversion, "surface_testSurfaceConversion", "Tests surface conversion.", TEST_ENABLED
+};
 
-static const SDLTest_TestCaseReference surfaceTest6 =
-        { (SDLTest_TestCaseFp)surface_testCompleteSurfaceConversion, "surface_testCompleteSurfaceConversion", "Tests surface conversion across all pixel formats", TEST_ENABLED};
+static const SDLTest_TestCaseReference surfaceTest6 = {
+    (SDLTest_TestCaseFp)surface_testCompleteSurfaceConversion, "surface_testCompleteSurfaceConversion", "Tests surface conversion across all pixel formats", TEST_ENABLED
+};
 
-static const SDLTest_TestCaseReference surfaceTest7 =
-        { (SDLTest_TestCaseFp)surface_testBlitColorMod, "surface_testBlitColorMod", "Tests some blitting routines with color mod.", TEST_ENABLED};
+static const SDLTest_TestCaseReference surfaceTest7 = {
+    (SDLTest_TestCaseFp)surface_testBlitColorMod, "surface_testBlitColorMod", "Tests some blitting routines with color mod.", TEST_ENABLED
+};
 
-static const SDLTest_TestCaseReference surfaceTest8 =
-        { (SDLTest_TestCaseFp)surface_testBlitAlphaMod, "surface_testBlitAlphaMod", "Tests some blitting routines with alpha mod.", TEST_ENABLED};
+static const SDLTest_TestCaseReference surfaceTest8 = {
+    (SDLTest_TestCaseFp)surface_testBlitAlphaMod, "surface_testBlitAlphaMod", "Tests some blitting routines with alpha mod.", TEST_ENABLED
+};
 
 /* TODO: rewrite test case, define new test data and re-enable; current implementation fails */
-static const SDLTest_TestCaseReference surfaceTest9 =
-        { (SDLTest_TestCaseFp)surface_testBlitBlendLoop, "surface_testBlitBlendLoop", "Test blitting routines with various blending modes", TEST_DISABLED};
+static const SDLTest_TestCaseReference surfaceTest9 = {
+    (SDLTest_TestCaseFp)surface_testBlitBlendLoop, "surface_testBlitBlendLoop", "Test blitting routines with various blending modes", TEST_DISABLED
+};
 
 /* TODO: rewrite test case, define new test data and re-enable; current implementation fails */
-static const SDLTest_TestCaseReference surfaceTest10 =
-        { (SDLTest_TestCaseFp)surface_testBlitBlendBlend, "surface_testBlitBlendBlend", "Tests blitting routines with blend blending mode.", TEST_DISABLED};
+static const SDLTest_TestCaseReference surfaceTest10 = {
+    (SDLTest_TestCaseFp)surface_testBlitBlendBlend, "surface_testBlitBlendBlend", "Tests blitting routines with blend blending mode.", TEST_DISABLED
+};
 
 /* TODO: rewrite test case, define new test data and re-enable; current implementation fails */
-static const SDLTest_TestCaseReference surfaceTest11 =
-        { (SDLTest_TestCaseFp)surface_testBlitBlendAdd, "surface_testBlitBlendAdd", "Tests blitting routines with add blending mode.", TEST_DISABLED};
+static const SDLTest_TestCaseReference surfaceTest11 = {
+    (SDLTest_TestCaseFp)surface_testBlitBlendAdd, "surface_testBlitBlendAdd", "Tests blitting routines with add blending mode.", TEST_DISABLED
+};
 
-static const SDLTest_TestCaseReference surfaceTest12 =
-        { (SDLTest_TestCaseFp)surface_testBlitBlendMod, "surface_testBlitBlendMod", "Tests blitting routines with mod blending mode.", TEST_ENABLED};
+static const SDLTest_TestCaseReference surfaceTest12 = {
+    (SDLTest_TestCaseFp)surface_testBlitBlendMod, "surface_testBlitBlendMod", "Tests blitting routines with mod blending mode.", TEST_ENABLED
+};
 
-static const SDLTest_TestCaseReference surfaceTestOverflow =
-        { surface_testOverflow, "surface_testOverflow", "Test overflow detection.", TEST_ENABLED};
+static const SDLTest_TestCaseReference surfaceTestOverflow = {
+    surface_testOverflow, "surface_testOverflow", "Test overflow detection.", TEST_ENABLED
+};
 
 /* Sequence of Surface test cases */
-static const SDLTest_TestCaseReference *surfaceTests[] =  {
+static const SDLTest_TestCaseReference *surfaceTests[] = {
     &surfaceTest1, &surfaceTest2, &surfaceTest3, &surfaceTest4, &surfaceTest5,
     &surfaceTest6, &surfaceTest7, &surfaceTest8, &surfaceTest9, &surfaceTest10,
     &surfaceTest11, &surfaceTest12, &surfaceTestOverflow, NULL
